@@ -1,21 +1,8 @@
 /*
- *   Copyright 2010 by Marco Martin <mart@kde.org>
+    SPDX-FileCopyrightText: 2010 Marco Martin <mart@kde.org>
 
- *   This program is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU Library General Public License as
- *   published by the Free Software Foundation; either version 2, or
- *   (at your option) any later version.
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details
- *
- *   You should have received a copy of the GNU Library General Public
- *   License along with this program; if not, write to the
- *   Free Software Foundation, Inc.,
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
- */
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #include "datamodel.h"
 #include "datasource.h"
@@ -26,19 +13,15 @@
 
 namespace Plasma
 {
-
 SortFilterModel::SortFilterModel(QObject *parent)
     : QSortFilterProxyModel(parent)
 {
     setObjectName(QStringLiteral("SortFilterModel"));
     setDynamicSortFilter(true);
-    connect(this, &QAbstractItemModel::rowsInserted,
-            this, &SortFilterModel::countChanged);
-    connect(this, &QAbstractItemModel::rowsRemoved,
-            this, &SortFilterModel::countChanged);
-    connect(this, &QAbstractItemModel::modelReset,
-            this, &SortFilterModel::countChanged);
-    connect(this,  &SortFilterModel::countChanged, this, &SortFilterModel::syncRoleNames);
+    connect(this, &QAbstractItemModel::rowsInserted, this, &SortFilterModel::countChanged);
+    connect(this, &QAbstractItemModel::rowsRemoved, this, &SortFilterModel::countChanged);
+    connect(this, &QAbstractItemModel::modelReset, this, &SortFilterModel::countChanged);
+    connect(this, &SortFilterModel::countChanged, this, &SortFilterModel::syncRoleNames);
 }
 
 SortFilterModel::~SortFilterModel()
@@ -62,10 +45,10 @@ void SortFilterModel::syncRoleNames()
     setSortRole(m_sortRole);
 }
 
-QHash<int,QByteArray> SortFilterModel::roleNames() const
+QHash<int, QByteArray> SortFilterModel::roleNames() const
 {
     if (sourceModel()) {
-       return sourceModel()->roleNames();
+        return sourceModel()->roleNames();
     }
     return {};
 }
@@ -92,10 +75,10 @@ void SortFilterModel::setModel(QAbstractItemModel *model)
         syncRoleNames();
     }
 
-    emit sourceModelChanged(model);
+    Q_EMIT sourceModelChanged(model);
 }
 
-bool SortFilterModel::filterAcceptsRow(int source_row, const QModelIndex& source_parent) const
+bool SortFilterModel::filterAcceptsRow(int source_row, const QModelIndex &source_parent) const
 {
     if (m_filterCallback.isCallable()) {
         QJSValueList args;
@@ -116,13 +99,13 @@ void SortFilterModel::setFilterRegExp(const QString &exp)
     if (exp == filterRegExp()) {
         return;
     }
-    QSortFilterProxyModel::setFilterRegExp(QRegExp(exp, Qt::CaseInsensitive));
+    QSortFilterProxyModel::setFilterRegularExpression(QRegularExpression(exp, QRegularExpression::CaseInsensitiveOption));
     Q_EMIT filterRegExpChanged(exp);
 }
 
 QString SortFilterModel::filterRegExp() const
 {
-    return QSortFilterProxyModel::filterRegExp().pattern();
+    return QSortFilterProxyModel::filterRegularExpression().pattern();
 }
 
 void SortFilterModel::setFilterString(const QString &filterString)
@@ -145,7 +128,7 @@ QJSValue SortFilterModel::filterCallback() const
     return m_filterCallback;
 }
 
-void SortFilterModel::setFilterCallback(const QJSValue& callback)
+void SortFilterModel::setFilterCallback(const QJSValue &callback)
 {
     if (m_filterCallback.strictlyEquals(callback)) {
         return;
@@ -202,7 +185,7 @@ void SortFilterModel::setSortColumn(int column)
         return;
     }
     sort(column, sortOrder());
-    emit sortColumnChanged();
+    Q_EMIT sortColumnChanged();
 }
 
 QVariantMap SortFilterModel::get(int row) const
@@ -235,42 +218,45 @@ int SortFilterModel::mapRowFromSource(int row) const
 }
 
 DataModel::DataModel(QObject *parent)
-    : QAbstractItemModel(parent),
-      m_dataSource(nullptr),
-      m_maxRoleId(Qt::UserRole + 1)
+    : QAbstractItemModel(parent)
+    , m_dataSource(nullptr)
+    , m_maxRoleId(Qt::UserRole + 1)
 {
-    //There is one reserved role name: DataEngineSource
+    // There is one reserved role name: DataEngineSource
     m_roleNames[m_maxRoleId] = QByteArrayLiteral("DataEngineSource");
     m_roleIds[QStringLiteral("DataEngineSource")] = m_maxRoleId;
     ++m_maxRoleId;
 
     setObjectName(QStringLiteral("DataModel"));
-    connect(this, &QAbstractItemModel::rowsInserted,
-            this, &DataModel::countChanged);
-    connect(this, &QAbstractItemModel::rowsRemoved,
-            this, &DataModel::countChanged);
-    connect(this, &QAbstractItemModel::modelReset,
-            this, &DataModel::countChanged);
+    connect(this, &QAbstractItemModel::rowsInserted, this, &DataModel::countChanged);
+    connect(this, &QAbstractItemModel::rowsRemoved, this, &DataModel::countChanged);
+    connect(this, &QAbstractItemModel::modelReset, this, &DataModel::countChanged);
 }
 
 DataModel::~DataModel()
 {
 }
 
+static bool isExactMatch(const QRegularExpression &re, const QString &s)
+{
+    const auto match = re.match(s);
+    return match.hasMatch() && s.size() == match.capturedLength();
+}
+
 void DataModel::dataUpdated(const QString &sourceName, const QVariantMap &data)
 {
-    if (!m_sourceFilter.isEmpty() && m_sourceFilterRE.isValid() && !m_sourceFilterRE.exactMatch(sourceName)) {
+    if (!m_sourceFilter.isEmpty() && m_sourceFilterRE.isValid() && !isExactMatch(m_sourceFilterRE, sourceName)) {
         return;
     }
 
     if (m_keyRoleFilter.isEmpty()) {
-        //an item is represented by a source: keys are roles m_roleLevel == FirstLevel
+        // an item is represented by a source: keys are roles m_roleLevel == FirstLevel
         QVariantList list;
 
         if (!m_dataSource->data()->isEmpty()) {
             const auto lst = m_dataSource->data()->keys();
             for (const QString &key : lst) {
-                if (!m_sourceFilter.isEmpty() && m_sourceFilterRE.isValid() && !m_sourceFilterRE.exactMatch(key)) {
+                if (!m_sourceFilter.isEmpty() && m_sourceFilterRE.isValid() && !isExactMatch(m_sourceFilterRE, key)) {
                     continue;
                 }
                 QVariant value = m_dataSource->data()->value(key);
@@ -283,16 +269,15 @@ void DataModel::dataUpdated(const QString &sourceName, const QVariantMap &data)
         }
         setItems(QString(), list);
     } else {
-        //a key that matches the one we want exists and is a list of DataEngine::Data
-        if (data.contains(m_keyRoleFilter) &&
-                data.value(m_keyRoleFilter).canConvert<QVariantList>()) {
+        // a key that matches the one we want exists and is a list of DataEngine::Data
+        if (data.contains(m_keyRoleFilter) && data.value(m_keyRoleFilter).canConvert<QVariantList>()) {
             setItems(sourceName, data.value(m_keyRoleFilter).value<QVariantList>());
         } else if (m_keyRoleFilterRE.isValid()) {
-            //try to match the key we want with a regular expression if set
+            // try to match the key we want with a regular expression if set
             QVariantList list;
             QVariantMap::const_iterator i;
             for (i = data.constBegin(); i != data.constEnd(); ++i) {
-                if (m_keyRoleFilterRE.exactMatch(i.key())) {
+                if (isExactMatch(m_keyRoleFilterRE, i.key())) {
                     list.append(i.value());
                 }
             }
@@ -323,12 +308,9 @@ void DataModel::setDataSource(QObject *object)
         dataUpdated(key, m_dataSource->data()->value(key).value<Plasma::DataEngine::Data>());
     }
 
-    connect(m_dataSource, &DataSource::newData,
-            this, &DataModel::dataUpdated);
-    connect(m_dataSource, &DataSource::sourceRemoved,
-            this, &DataModel::removeSource);
-    connect(m_dataSource, &DataSource::sourceDisconnected,
-            this, &DataModel::removeSource);
+    connect(m_dataSource, &DataSource::newData, this, &DataModel::dataUpdated);
+    connect(m_dataSource, &DataSource::sourceRemoved, this, &DataModel::removeSource);
+    connect(m_dataSource, &DataSource::sourceDisconnected, this, &DataModel::removeSource);
 }
 
 QObject *DataModel::dataSource() const
@@ -350,7 +332,7 @@ void DataModel::setKeyRoleFilter(const QString &key)
     }
 
     m_keyRoleFilter = key;
-    m_keyRoleFilterRE = QRegExp(m_keyRoleFilter);
+    m_keyRoleFilterRE = QRegularExpression(m_keyRoleFilter);
 }
 
 QString DataModel::keyRoleFilter() const
@@ -365,7 +347,7 @@ void DataModel::setSourceFilter(const QString &key)
     }
 
     m_sourceFilter = key;
-    m_sourceFilterRE = QRegExp(key);
+    m_sourceFilterRE = QRegularExpression(key);
     /*
      FIXME: if the user changes the source filter, it won't immediately be reflected in the
      available data
@@ -386,18 +368,18 @@ void DataModel::setItems(const QString &sourceName, const QVariantList &list)
     const int delta = list.length() - oldLength;
     const bool firstRun = m_items.isEmpty();
 
-    //At what row number the first item associated to this source starts
+    // At what row number the first item associated to this source starts
     int sourceIndex = 0;
-    QMap<QString, QVector<QVariant> >::const_iterator i;
+    QMap<QString, QVector<QVariant>>::const_iterator i;
     for (i = m_items.constBegin(); i != m_items.constEnd(); ++i) {
         if (i.key() == sourceName) {
             break;
         }
         sourceIndex += i.value().count();
     }
-    //signal as inserted the rows at the end, all the other rows will signal a dataupdated.
-    //better than a model reset because doesn't cause deletion and re-creation of every list item on a qml ListView, repeaters etc.
-    //the first run it gets reset because otherwise setRoleNames gets broken
+    // signal as inserted the rows at the end, all the other rows will signal a dataupdated.
+    // better than a model reset because doesn't cause deletion and re-creation of every list item on a qml ListView, repeaters etc.
+    // the first run it gets reset because otherwise setRoleNames gets broken
     if (firstRun) {
         beginResetModel();
     } else if (delta > 0) {
@@ -405,7 +387,7 @@ void DataModel::setItems(const QString &sourceName, const QVariantList &list)
     } else if (delta < 0) {
         beginRemoveRows(QModelIndex(), sourceIndex + list.length(), sourceIndex + oldLength - 1);
     }
-    //convert to vector, so data() will be O(1)
+    // convert to vector, so data() will be O(1)
     m_items[sourceName] = list.toVector();
 
     if (!list.isEmpty()) {
@@ -447,8 +429,7 @@ void DataModel::setItems(const QString &sourceName, const QVariantList &list)
     } else if (delta < 0) {
         endRemoveRows();
     }
-    emit dataChanged(createIndex(sourceIndex, 0),
-                     createIndex(sourceIndex + qMin(list.length(), oldLength), 0));
+    Q_EMIT dataChanged(createIndex(sourceIndex, 0), createIndex(sourceIndex + qMin(list.length(), oldLength), 0));
 }
 
 QHash<int, QByteArray> DataModel::roleNames() const
@@ -458,10 +439,10 @@ QHash<int, QByteArray> DataModel::roleNames() const
 
 void DataModel::removeSource(const QString &sourceName)
 {
-    //FIXME: find a way to remove only the proper things also in the case where sources are items
+    // FIXME: find a way to remove only the proper things also in the case where sources are items
 
     if (m_keyRoleFilter.isEmpty()) {
-        //source name in the map, linear scan
+        // source name in the map, linear scan
         for (int i = 0; i < m_items.value(QString()).count(); ++i) {
             if (m_items.value(QString())[i].value<QVariantMap>().value(QStringLiteral("DataEngineSource")) == sourceName) {
                 beginRemoveRows(QModelIndex(), i, i);
@@ -472,7 +453,7 @@ void DataModel::removeSource(const QString &sourceName)
         }
     } else {
         if (m_items.contains(sourceName)) {
-            //At what row number the first item associated to this source starts
+            // At what row number the first item associated to this source starts
             int sourceIndex = 0;
             for (auto i = m_items.constBegin(); i != m_items.constEnd(); ++i) {
                 if (i.key() == sourceName) {
@@ -481,7 +462,7 @@ void DataModel::removeSource(const QString &sourceName)
                 sourceIndex += i.value().count();
             }
 
-            //source name as key of the map
+            // source name as key of the map
 
             int count = m_items.value(sourceName).count();
             if (count > 0) {
@@ -497,15 +478,14 @@ void DataModel::removeSource(const QString &sourceName)
 
 QVariant DataModel::data(const QModelIndex &index, int role) const
 {
-    if (!index.isValid() || index.column() > 0 ||
-            index.row() < 0 || index.row() >= countItems()) {
+    if (!index.isValid() || index.column() > 0 || index.row() < 0 || index.row() >= countItems()) {
         return QVariant();
     }
 
     int count = 0;
     int actualRow = 0;
     QString source;
-    QMap<QString, QVector<QVariant> >::const_iterator i;
+    QMap<QString, QVector<QVariant>>::const_iterator i;
     for (i = m_items.constBegin(); i != m_items.constEnd(); ++i) {
         const int oldCount = count;
         count += i.value().count();
@@ -517,8 +497,8 @@ QVariant DataModel::data(const QModelIndex &index, int role) const
         }
     }
 
-    //is it the reserved role: DataEngineSource ?
-    //also, if each source is an item DataEngineSource is a role between all the others, otherwise we know it from the role variable
+    // is it the reserved role: DataEngineSource ?
+    // also, if each source is an item DataEngineSource is a role between all the others, otherwise we know it from the role variable
     if (!m_keyRoleFilter.isEmpty() && m_roleNames.value(role) == "DataEngineSource") {
         return source;
     } else {
@@ -553,8 +533,8 @@ QModelIndex DataModel::parent(const QModelIndex &child) const
 
 int DataModel::rowCount(const QModelIndex &parent) const
 {
-    //this is not a tree
-    //TODO: make it possible some day?
+    // this is not a tree
+    // TODO: make it possible some day?
     if (parent.isValid()) {
         return 0;
     }
@@ -585,4 +565,3 @@ QVariantMap DataModel::get(int row) const
 }
 
 }
-
