@@ -1,35 +1,25 @@
 /*
- *   Copyright 2012 Marco Martin <mart@kde.org>
- *   Copyright 2014 David Edmundson <davidedmudnson@kde.org>
- *
- *   This program is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU Library General Public License as
- *   published by the Free Software Foundation; either version 2, or
- *   (at your option) any later version.
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details
- *
- *   You should have received a copy of the GNU Library General Public
- *   License along with this program; if not, write to the
- *   Free Software Foundation, Inc.,
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
- */
+    SPDX-FileCopyrightText: 2012 Marco Martin <mart@kde.org>
+    SPDX-FileCopyrightText: 2014 David Edmundson <davidedmudnson@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #ifndef ICONITEM_H
 #define ICONITEM_H
 
 #include <QIcon>
-#include <QQuickItem>
 #include <QPixmap>
-#include <QVariant>
+#include <QPointer>
+#include <QQuickItem>
 #include <QTimer>
+#include <QVariant>
 
 #include <plasma/svg.h>
 
 class QPropertyAnimation;
+class IconItemSource;
+class SvgSource;
 
 /**
  * @class IconItem
@@ -61,15 +51,9 @@ class IconItem : public QQuickItem
     Q_PROPERTY(Plasma::Theme::ColorGroup colorGroup READ colorGroup WRITE setColorGroup NOTIFY colorGroupChanged)
 
     /**
-      * Specifies the overlay(s) for this icon
-      */
-    Q_PROPERTY(QStringList overlays READ overlays WRITE setOverlays NOTIFY overlaysChanged)
-
-    /**
-     * See QQuickItem::smooth
+     * Specifies the overlay(s) for this icon
      */
-    //KF6 Remove, this just shadows QQuickItem::smooth
-    Q_PROPERTY(bool smooth READ smooth WRITE setSmooth NOTIFY smoothChanged)
+    Q_PROPERTY(QStringList overlays READ overlays WRITE setOverlays NOTIFY overlaysChanged)
 
     /**
      * Apply a visual indication that this icon is active.
@@ -126,7 +110,7 @@ class IconItem : public QQuickItem
 
 public:
     explicit IconItem(QQuickItem *parent = nullptr);
-    ~IconItem() Q_DECL_OVERRIDE;
+    ~IconItem() override;
 
     void setSource(const QVariant &source);
     QVariant source() const;
@@ -140,9 +124,6 @@ public:
     bool isActive() const;
     void setActive(bool active);
 
-    void setSmooth(const bool smooth);
-    bool smooth() const;
-
     bool isAnimated() const;
     void setAnimated(bool animated);
 
@@ -163,20 +144,22 @@ public:
     void setImplicitHeight2(int height);
     void setImplicitWidth2(int height);
 
-    void updatePolish() Q_DECL_OVERRIDE;
-    QSGNode* updatePaintNode(QSGNode * oldNode, UpdatePaintNodeData * updatePaintNodeData) Q_DECL_OVERRIDE;
+    void updatePolish() override;
+    QSGNode *updatePaintNode(QSGNode *oldNode, UpdatePaintNodeData *updatePaintNodeData) override;
 
-    void itemChange(ItemChange change, const ItemChangeData &value) Q_DECL_OVERRIDE;
-    void geometryChanged(const QRectF &newGeometry,
-                         const QRectF &oldGeometry) Q_DECL_OVERRIDE;
+    void itemChange(ItemChange change, const ItemChangeData &value) override;
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+    void geometryChanged(const QRectF &newGeometry, const QRectF &oldGeometry) override;
+#else
+    void geometryChange(const QRectF &newGeometry, const QRectF &oldGeometry) override;
+#endif
 
-    void componentComplete() Q_DECL_OVERRIDE;
+    void componentComplete() override;
 
 Q_SIGNALS:
     void overlaysChanged();
     void activeChanged();
     void sourceChanged();
-    void smoothChanged();
     void animatedChanged();
     void usesPlasmaThemeChanged();
     void roundToIconSizeChanged();
@@ -192,22 +175,20 @@ private Q_SLOTS:
     void animationFinished();
     void valueChanged(const QVariant &value);
     void onEnabledChanged();
+    void iconLoaderIconChanged(int group);
+    void windowVisibleChanged(bool visible);
 
 private:
     void loadPixmap();
     QSize paintedSize(const QSizeF &containerSize = QSizeF()) const;
     void updateImplicitSize();
 
-    //all the ways we can set an source. Only one of them will be valid
-    QIcon m_icon;
-    Plasma::Svg *m_svgIcon;
-    QString m_svgIconName;
-    QImage m_imageIcon;
-    //this contains the raw variant it was passed
+    // all the ways we can set an source. Only one of them will be valid
+    QScopedPointer<IconItemSource> m_iconItemSource;
+    // this contains the raw variant it was passed
     QVariant m_source;
     Plasma::Svg::Status m_status;
 
-    bool m_smooth;
     bool m_active;
     bool m_animated;
     bool m_usesPlasmaTheme;
@@ -227,9 +208,14 @@ private:
 
     Plasma::Theme::ColorGroup m_colorGroup;
 
-    //animation on pixmap change
+    // animation on pixmap change
     QPropertyAnimation *m_animation;
     qreal m_animValue;
+
+    QPointer<QWindow> m_window;
+
+    // to access schedulePixmapUpdate private slot
+    friend class SvgSource;
 };
 
 #endif
