@@ -6,20 +6,22 @@
 
 #include "tooltipdialog.h"
 
+#include <QDebug>
+#include <QFile>
+#include <QPlatformSurfaceEvent>
 #include <QQmlEngine>
 #include <QQuickItem>
-#include <QDebug>
-#include <QPlatformSurfaceEvent>
 
-#include <kdeclarative/qmlobjectsharedengine.h>
 #include <KWindowSystem>
+#include <kdeclarative/qmlobjectsharedengine.h>
 
-ToolTipDialog::ToolTipDialog(QQuickItem  *parent)
-    : Dialog(parent),
-      m_qmlObject(nullptr),
-      m_hideTimeout(4000),
-      m_interactive(false),
-      m_owner(nullptr)
+ToolTipDialog::ToolTipDialog(QQuickItem *parent)
+    : Dialog(parent)
+    , m_qmlObject(nullptr)
+    , m_hideTimeout(4000)
+    , m_interactive(false)
+    , m_extendTimeoutFlag(m_extendTimeoutFlags::None)
+    , m_owner(nullptr)
 {
     setLocation(Plasma::Types::Floating);
     setType(Dialog::WindowType::Tooltip);
@@ -42,7 +44,7 @@ QQuickItem *ToolTipDialog::loadDefaultItem()
     }
 
     if (!m_qmlObject->rootObject()) {
-        //HACK: search our own import
+        // HACK: search our own import
         const auto paths = m_qmlObject->engine()->importPathList();
         for (const QString &path : paths) {
             if (QFile::exists(path + QStringLiteral("/org/kde/plasma/core"))) {
@@ -77,12 +79,29 @@ void ToolTipDialog::resizeEvent(QResizeEvent *re)
 
 bool ToolTipDialog::event(QEvent *e)
 {
-    if (e->type() == QEvent::Enter) {
+    switch (e->type())
+    {
+    case QEvent::Enter:
         if (m_interactive) {
             m_showTimer->stop();
         }
-    } else if (e->type() == QEvent::Leave) {
-        dismiss();
+        break;
+    case QEvent::Leave:
+        if (m_extendTimeoutFlag == (m_extendTimeoutFlags::Resized | m_extendTimeoutFlags::Moved)) { 
+            keepalive(); // HACK: prevent tooltips from being incorrectly dismissed (BUG439522)
+        } else {
+            dismiss();
+        }
+        m_extendTimeoutFlag = m_extendTimeoutFlags::None;
+        break;
+    case QEvent::Resize:
+        m_extendTimeoutFlag = m_extendTimeoutFlags::Resized;
+        break;
+    case QEvent::Move:
+        m_extendTimeoutFlag |= m_extendTimeoutFlags::Moved;
+        break;
+    case QEvent::MouseMove:
+        m_extendTimeoutFlag = m_extendTimeoutFlags::None;
     }
 
     bool ret = Dialog::event(e);
