@@ -9,8 +9,8 @@
 
 #include "dialog.h"
 
-#include <QTimer>
 #include <QQuickWindow>
+#include <QTimer>
 #include <QVariant>
 
 class QQuickItem;
@@ -62,6 +62,15 @@ private:
     QTimer *m_showTimer;
     int m_hideTimeout;
     bool m_interactive;
+    /**
+     * HACK: prevent tooltips from being incorrectly dismissed (BUG439522)
+     */
+    enum m_extendTimeoutFlags {
+        None = 0x0,
+        Resized = 0x1,
+        Moved = 0x2,
+    };
+    int m_extendTimeoutFlag;
     QObject *m_owner;
 };
 
