@@ -8,20 +8,19 @@
 
 #include "units.h"
 
-#include <QGuiApplication>
 #include <QDebug>
-#include <QtGlobal>
+#include <QFontMetrics>
+#include <QGuiApplication>
 #include <QQuickItem>
 #include <QQuickWindow>
 #include <QScreen>
-#include <QFontMetrics>
+#include <QtGlobal>
 #include <cmath>
 
 #include <KIconLoader>
 
 const int defaultLongDuration = 200;
 
-
 SharedAppFilter::SharedAppFilter(QObject *parent)
     : QObject(parent)
 {
@@ -29,7 +28,8 @@ SharedAppFilter::SharedAppFilter(QObject *parent)
 }
 
 SharedAppFilter::~SharedAppFilter()
-{}
+{
+}
 
 bool SharedAppFilter::eventFilter(QObject *watched, QEvent *event)
 {
@@ -44,12 +44,13 @@ bool SharedAppFilter::eventFilter(QObject *watched, QEvent *event)
 SharedAppFilter *Units::s_sharedAppFilter = nullptr;
 
 Units::Units(QObject *parent)
-    : QObject(parent),
-      m_gridUnit(-1),
-      m_devicePixelRatio(-1),
-      m_smallSpacing(-1),
-      m_largeSpacing(-1),
-      m_longDuration(defaultLongDuration) // default base value for animations
+    : QObject(parent)
+    , m_gridUnit(-1)
+    , m_devicePixelRatio(-1)
+    , m_smallSpacing(-1)
+    , m_mediumSpacing(-1)
+    , m_largeSpacing(-1)
+    , m_longDuration(defaultLongDuration) // default base value for animations
 {
     if (!s_sharedAppFilter) {
         s_sharedAppFilter = new SharedAppFilter();
@@ -64,18 +65,16 @@ Units::Units(QObject *parent)
     QObject::connect(s_sharedAppFilter, &SharedAppFilter::fontChanged, this, &Units::updateSpacing);
 
     m_animationSpeedWatcher = KConfigWatcher::create(KSharedConfig::openConfig());
-    connect(m_animationSpeedWatcher.data(), &KConfigWatcher::configChanged, this,
-        [this](const KConfigGroup &group, const QByteArrayList &names) {
-            if (group.name() == QLatin1String("KDE") && names.contains(QByteArrayLiteral("AnimationDurationFactor"))) {
-                updateAnimationSpeed();
-            }
+    connect(m_animationSpeedWatcher.data(), &KConfigWatcher::configChanged, this, [this](const KConfigGroup &group, const QByteArrayList &names) {
+        if (group.name() == QLatin1String("KDE") && names.contains(QByteArrayLiteral("AnimationDurationFactor"))) {
+            updateAnimationSpeed();
+        }
     });
     updateAnimationSpeed();
 }
 
 Units::~Units()
 {
-
 }
 
 Units &Units::instance()
@@ -105,7 +104,6 @@ void Units::updateAnimationSpeed()
     }
 }
 
-
 void Units::iconLoaderSettingsChanged()
 {
     m_iconSizes->insert(QStringLiteral("desktop"), devicePixelIconSize(KIconLoader::global()->currentSize(KIconLoader::Desktop)));
@@ -117,6 +115,8 @@ void Units::iconLoaderSettingsChanged()
     m_iconSizes->insert(QStringLiteral("large"), devicePixelIconSize(KIconLoader::SizeLarge));
     m_iconSizes->insert(QStringLiteral("huge"), devicePixelIconSize(KIconLoader::SizeHuge));
     m_iconSizes->insert(QStringLiteral("enormous"), devicePixelIconSize(KIconLoader::SizeEnormous));
+    // gridUnit is always the font height here
+    m_iconSizes->insert(QStringLiteral("sizeForLabels"), devicePixelIconSize(roundToIconSize(QFontMetrics(QGuiApplication::font()).height())));
 
     m_iconSizeHints->insert(QStringLiteral("panel"), devicePixelIconSize(KIconLoader::global()->currentSize(KIconLoader::Panel)));
     m_iconSizeHints->insert(QStringLiteral("desktop"), devicePixelIconSize(KIconLoader::global()->currentSize(KIconLoader::Desktop)));
@@ -137,28 +137,60 @@ QQmlPropertyMap *Units::iconSizeHints() const
 
 int Units::roundToIconSize(int size)
 {
-    /*Do *not* use devicePixelIconSize here, we want to use the sizes of the pixmaps of the smallest icons on the disk. And those are unaffected by dpi*/
+    // If not using Qt scaling (e.g. on X11 by default), manually scale all sizes
+    // according to the DPR because Qt hasn't done it for us. Otherwise all
+    // returned sizes are too small and icons are only the right size by pure
+    // chance for the larger sizes due to their large differences in size
+    qreal multiplier = 1.0;
+    QScreen *primary = QGuiApplication::primaryScreen();
+    if (primary) {
+        // Note that when using Qt scaling, the multiplier will always be 1
+        // because Qt will scale everything for us. This is good and intentional.
+        multiplier = bestIconScaleForDevicePixelRatio((qreal)primary->logicalDotsPerInchX() / (qreal)96);
+    }
+
     if (size <= 0) {
         return 0;
-    } else if (size < KIconLoader::SizeSmall) {
-        return KIconLoader::SizeSmall/2;
-    } else if (size < KIconLoader::SizeSmallMedium) {
-        return KIconLoader::SizeSmall;
 
-    } else if (size < KIconLoader::SizeMedium) {
-        return KIconLoader::SizeSmallMedium;
+    } else if (size < KIconLoader::SizeSmall * multiplier) {
+        return qRound(KIconLoader::SizeSmall * multiplier);
 
-    } else if (size < KIconLoader::SizeLarge) {
-        return KIconLoader::SizeMedium;
+    } else if (size < KIconLoader::SizeSmallMedium * multiplier) {
+        return qRound(KIconLoader::SizeSmall * multiplier);
 
-    } else if (size < KIconLoader::SizeHuge) {
-        return KIconLoader::SizeLarge;
+    } else if (size < KIconLoader::SizeMedium * multiplier) {
+        return qRound(KIconLoader::SizeSmallMedium * multiplier);
+
+    } else if (size < KIconLoader::SizeLarge * multiplier) {
+        return qRound(KIconLoader::SizeMedium * multiplier);
+
+    } else if (size < KIconLoader::SizeHuge * multiplier) {
+        return qRound(KIconLoader::SizeLarge * multiplier);
+
+    } else if (size < KIconLoader::SizeEnormous * multiplier) {
+        return qRound(KIconLoader::SizeHuge * multiplier);
 
     } else {
         return size;
     }
 }
 
+qreal Units::bestIconScaleForDevicePixelRatio(const qreal ratio)
+{
+    if (ratio < 1.5) {
+        return 1;
+    } else if (ratio < 2.0) {
+        return 1.5;
+    } else if (ratio < 2.5) {
+        return 2.0;
+    } else if (ratio < 3.0) {
+        return 2.5;
+    } else if (ratio < 3.5) {
+        return 3.0;
+    } else {
+        return ratio;
+    }
+}
 int Units::devicePixelIconSize(const int size) const
 {
     /* in kiconloader.h
@@ -176,20 +208,7 @@ int Units::devicePixelIconSize(const int size) const
     // and multiplies the global settings with the dpi ratio.
     const qreal ratio = devicePixelRatio();
 
-    if (ratio < 1.5) {
-        return size;
-    } else if (ratio < 2.0) {
-        return size * 1.5;
-    } else if (ratio < 2.5) {
-        return size * 2.0;
-    } else if (ratio < 3.0) {
-        return size * 2.5;
-    } else if (ratio < 3.5) {
-        return size * 3.0;
-    } else {
-        return size * ratio;
-    }
-    // FIXME: Add special casing for < 64 cases: align to kiconloader size
+    return size * bestIconScaleForDevicePixelRatio(ratio);
 }
 
 qreal Units::devicePixelRatio() const
@@ -227,6 +246,11 @@ int Units::smallSpacing() const
     return m_smallSpacing;
 }
 
+int Units::mediumSpacing() const
+{
+    return m_mediumSpacing;
+}
+
 int Units::largeSpacing() const
 {
     return m_largeSpacing;
@@ -246,6 +270,7 @@ void Units::updateSpacing()
 
     if (gridUnit != m_largeSpacing) {
         m_smallSpacing = qMax(2, (int)(gridUnit / 4)); // 1/4 of gridUnit, at least 2
+        m_mediumSpacing = std::round(m_smallSpacing * 1.5);
         m_largeSpacing = gridUnit; // msize.height
         Q_EMIT spacingChanged();
     }
@@ -263,7 +288,7 @@ int Units::shortDuration() const
 
 int Units::veryShortDuration() const
 {
-	return qRound(m_longDuration * 0.25);
+    return qRound(m_longDuration * 0.25);
 }
 
 int Units::veryLongDuration() const
@@ -271,5 +296,9 @@ int Units::veryLongDuration() const
     return m_longDuration * 2;
 }
 
-#include "moc_units.cpp"
+int Units::humanMoment() const
+{
+    return 2000;
+}
 
+#include "moc_units.cpp"
