@@ -12,21 +12,25 @@
 #include <QOpenGLContext>
 #include <QQuickWindow>
 #include <QRunnable>
+#include <QSGImageNode>
 
 // X11
 #if HAVE_XCB_COMPOSITE
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+#include <private/qtx11extras_p.h>
+#else
 #include <QX11Info>
+#endif
 #include <xcb/composite.h>
 #if HAVE_GLX
 #include <GL/glx.h>
-typedef void (*glXBindTexImageEXT_func)(Display *dpy, GLXDrawable drawable,
-                                        int buffer, const int *attrib_list);
+typedef void (*glXBindTexImageEXT_func)(Display *dpy, GLXDrawable drawable, int buffer, const int *attrib_list);
 typedef void (*glXReleaseTexImageEXT_func)(Display *dpy, GLXDrawable drawable, int buffer);
 #endif
 #if HAVE_EGL
-typedef EGLImageKHR(*eglCreateImageKHR_func)(EGLDisplay, EGLContext, EGLenum, EGLClientBuffer, const EGLint *);
-typedef EGLBoolean(*eglDestroyImageKHR_func)(EGLDisplay, EGLImageKHR);
-typedef GLvoid(*glEGLImageTargetTexture2DOES_func)(GLenum, GLeglImageOES);
+typedef EGLImageKHR (*eglCreateImageKHR_func)(EGLDisplay, EGLContext, EGLenum, EGLClientBuffer, const EGLint *);
+typedef EGLBoolean (*eglDestroyImageKHR_func)(EGLDisplay, EGLImageKHR);
+typedef GLvoid (*glEGLImageTargetTexture2DOES_func)(GLenum, GLeglImageOES);
 #endif // HAVE_EGL
 #endif
 
@@ -34,17 +38,31 @@ typedef GLvoid(*glEGLImageTargetTexture2DOES_func)(GLenum, GLeglImageOES);
 
 namespace Plasma
 {
+class DiscardTextureProviderRunnable : public QRunnable
+{
+public:
+    explicit DiscardTextureProviderRunnable(WindowTextureProvider *provider)
+        : m_provider(provider)
+    {
+    }
+
+    void run() override
+    {
+        delete m_provider;
+    }
+
+private:
+    WindowTextureProvider *m_provider;
+};
 
 #if HAVE_XCB_COMPOSITE
 #if HAVE_GLX
-class DiscardGlxPixmapRunnable : public QRunnable {
+class DiscardGlxPixmapRunnable : public QRunnable
+{
 public:
-    DiscardGlxPixmapRunnable(
-        uint,
-        QFunctionPointer,
-        xcb_pixmap_t
-    );
+    DiscardGlxPixmapRunnable(uint, QFunctionPointer, xcb_pixmap_t);
     void run() override;
+
 private:
     uint m_texture;
     QFunctionPointer m_releaseTexImage;
@@ -52,11 +70,12 @@ private:
 };
 
 DiscardGlxPixmapRunnable::DiscardGlxPixmapRunnable(uint texture, QFunctionPointer deleteFunction, xcb_pixmap_t pixmap)
-    : QRunnable(),
-    m_texture(texture),
-    m_releaseTexImage(deleteFunction),
-    m_glxPixmap(pixmap)
-{}
+    : QRunnable()
+    , m_texture(texture)
+    , m_releaseTexImage(deleteFunction)
+    , m_glxPixmap(pixmap)
+{
+}
 
 void DiscardGlxPixmapRunnable::run()
 {
@@ -67,17 +86,15 @@ void DiscardGlxPixmapRunnable::run()
         glDeleteTextures(1, &m_texture);
     }
 }
-#endif //HAVE_GLX
+#endif // HAVE_GLX
 
 #if HAVE_EGL
-class DiscardEglPixmapRunnable : public QRunnable {
+class DiscardEglPixmapRunnable : public QRunnable
+{
 public:
-    DiscardEglPixmapRunnable(
-        uint,
-        QFunctionPointer,
-        EGLImageKHR
-    );
+    DiscardEglPixmapRunnable(uint, QFunctionPointer, EGLImageKHR);
     void run() override;
+
 private:
     uint m_texture;
     QFunctionPointer m_eglDestroyImageKHR;
@@ -85,11 +102,12 @@ private:
 };
 
 DiscardEglPixmapRunnable::DiscardEglPixmapRunnable(uint texture, QFunctionPointer deleteFunction, EGLImageKHR image)
-    : QRunnable(),
-    m_texture(texture),
-    m_eglDestroyImageKHR(deleteFunction),
-    m_image(image)
-{}
+    : QRunnable()
+    , m_texture(texture)
+    , m_eglDestroyImageKHR(deleteFunction)
+    , m_image(image)
+{
+}
 
 void DiscardEglPixmapRunnable::run()
 {
@@ -98,22 +116,18 @@ void DiscardEglPixmapRunnable::run()
         glDeleteTextures(1, &m_texture);
     }
 }
-#endif//HAVE_EGL
-#endif //HAVE_XCB_COMPOSITE
+#endif // HAVE_EGL
+#endif // HAVE_XCB_COMPOSITE
 
-WindowTextureNode::WindowTextureNode()
-    : QSGSimpleTextureNode()
+QSGTexture *WindowTextureProvider::texture() const
 {
+    return m_texture.data();
 }
 
-WindowTextureNode::~WindowTextureNode()
+void WindowTextureProvider::setTexture(QSGTexture *texture)
 {
-}
-
-void WindowTextureNode::reset(QSGTexture *texture)
-{
-    setTexture(texture);
     m_texture.reset(texture);
+    Q_EMIT textureChanged();
 }
 
 WindowThumbnail::WindowThumbnail(QQuickItem *parent)
@@ -216,25 +230,25 @@ void WindowThumbnail::itemChange(ItemChange change, const ItemChangeData &data)
 
 void WindowThumbnail::releaseResources()
 {
+    QQuickWindow::RenderStage m_renderStage = QQuickWindow::NoStage;
+    if (m_textureProvider) {
+        window()->scheduleRenderJob(new DiscardTextureProviderRunnable(m_textureProvider), m_renderStage);
+        m_textureProvider = nullptr;
+    }
+
 #if HAVE_XCB_COMPOSITE
 
 #if HAVE_GLX && HAVE_EGL
-    //only one (or none) should be set, but never both
+    // only one (or none) should be set, but never both
     Q_ASSERT(m_glxPixmap == XCB_PIXMAP_NONE || m_image == EGL_NO_IMAGE_KHR);
 #endif
-#if HAVE_GLX || HAVE_EGL
-    QQuickWindow::RenderStage m_renderStage = QQuickWindow::NoStage;
-#endif
 
-    //data is deleted in the render thread (with relevant GLX calls)
-    //note runnable may be called *after* this is deleted
-    //but the pointer is held by the WindowThumbnail which is in the main thread
+    // data is deleted in the render thread (with relevant GLX calls)
+    // note runnable may be called *after* this is deleted
+    // but the pointer is held by the WindowThumbnail which is in the main thread
 #if HAVE_GLX
     if (m_glxPixmap != XCB_PIXMAP_NONE) {
-        window()->scheduleRenderJob(new DiscardGlxPixmapRunnable(m_texture,
-                                                        m_releaseTexImage,
-                                                        m_glxPixmap),
-                                                        m_renderStage);
+        window()->scheduleRenderJob(new DiscardGlxPixmapRunnable(m_texture, m_releaseTexImage, m_glxPixmap), m_renderStage);
 
         m_glxPixmap = XCB_PIXMAP_NONE;
         m_texture = 0;
@@ -242,11 +256,7 @@ void WindowThumbnail::releaseResources()
 #endif
 #if HAVE_EGL
     if (m_image != EGL_NO_IMAGE_KHR) {
-        window()->scheduleRenderJob(new DiscardEglPixmapRunnable(m_texture,
-                                                        m_eglDestroyImageKHR,
-                                                        m_image),
-                                                        m_renderStage);
-
+        window()->scheduleRenderJob(new DiscardEglPixmapRunnable(m_texture, m_eglDestroyImageKHR, m_image), m_renderStage);
         m_image = EGL_NO_IMAGE_KHR;
         m_texture = 0;
     }
@@ -254,8 +264,6 @@ void WindowThumbnail::releaseResources()
 #endif
 }
 
-
-
 uint32_t WindowThumbnail::winId() const
 {
     return m_winId;
@@ -281,7 +289,7 @@ void WindowThumbnail::setWinId(uint32_t winId)
         startRedirecting();
     }
 
-    emit winIdChanged();
+    Q_EMIT winIdChanged();
 }
 
 qreal WindowThumbnail::paintedWidth() const
@@ -302,21 +310,29 @@ bool WindowThumbnail::thumbnailAvailable() const
 QSGNode *WindowThumbnail::updatePaintNode(QSGNode *oldNode, UpdatePaintNodeData *updatePaintNodeData)
 {
     Q_UNUSED(updatePaintNodeData)
-    auto *node = static_cast<WindowTextureNode *>(oldNode);
+
+    if (!m_textureProvider) {
+        m_textureProvider = new WindowTextureProvider();
+    }
+
+    if (!m_xcb || m_winId == 0 || (window() && window()->winId() == m_winId)) {
+        iconToTexture(m_textureProvider);
+    } else {
+        windowToTexture(m_textureProvider);
+    }
+
+    QSGImageNode *node = static_cast<QSGImageNode *>(oldNode);
     if (!node) {
-        node = new WindowTextureNode();
+        node = window()->createImageNode();
+        qsgnode_set_description(node, QStringLiteral("windowthumbnail"));
         node->setFiltering(QSGTexture::Linear);
     }
-    if (!m_xcb || m_winId == 0 || (window() && window()->winId() == m_winId)) {
-        iconToTexture(node);
-    } else {
-        windowToTexture(node);
-    }
-    node->setRect(boundingRect());
+
+    node->setTexture(m_textureProvider->texture());
     const QSizeF size(node->texture()->textureSize().scaled(boundingRect().size().toSize(), Qt::KeepAspectRatio));
     if (size != m_paintedSize) {
         m_paintedSize = size;
-        emit paintedSizeChanged();
+        Q_EMIT paintedSizeChanged();
     }
     const qreal x = boundingRect().x() + (boundingRect().width() - size.width()) / 2;
     const qreal y = boundingRect().y() + (boundingRect().height() - size.height()) / 2;
@@ -324,7 +340,11 @@ QSGNode *WindowThumbnail::updatePaintNode(QSGNode *oldNode, UpdatePaintNodeData
     return node;
 }
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 bool WindowThumbnail::nativeEventFilter(const QByteArray &eventType, void *message, long int *result)
+#else
+bool WindowThumbnail::nativeEventFilter(const QByteArray &eventType, void *message, qintptr *result)
+#endif
 {
     Q_UNUSED(result)
     if (!m_xcb || !m_composite || eventType != QByteArrayLiteral("xcb_generic_event_t")) {
@@ -359,7 +379,7 @@ bool WindowThumbnail::nativeEventFilter(const QByteArray &eventType, void *messa
     return false;
 }
 
-void WindowThumbnail::iconToTexture(WindowTextureNode *textureNode)
+void WindowThumbnail::iconToTexture(WindowTextureProvider *textureProvider)
 {
     QIcon icon;
     if (KWindowSystem::self()->hasWId(m_winId)) {
@@ -369,12 +389,12 @@ void WindowThumbnail::iconToTexture(WindowTextureNode *textureNode)
         icon = QIcon::fromTheme(QStringLiteral("plasma"));
     }
     QImage image = icon.pixmap(window(), boundingRect().size().toSize()).toImage();
-    textureNode->reset(window()->createTextureFromImage(image, QQuickWindow::TextureCanUseAtlas));
+    textureProvider->setTexture(window()->createTextureFromImage(image, QQuickWindow::TextureCanUseAtlas));
 }
 
 #if HAVE_XCB_COMPOSITE
 #if HAVE_GLX
-bool WindowThumbnail::windowToTextureGLX(WindowTextureNode *textureNode)
+bool WindowThumbnail::windowToTextureGLX(WindowTextureProvider *textureProvider)
 {
     if (window()->openglContext()) {
         if (!m_openGLFunctionsResolved) {
@@ -405,9 +425,9 @@ bool WindowThumbnail::windowToTextureGLX(WindowTextureNode *textureNode)
                 return false;
             }
 
-            textureNode->reset(window()->createTextureFromId(m_texture, QSize(geo->width, geo->height), QQuickWindow::TextureCanUseAtlas));
+            textureProvider->setTexture(window()->createTextureFromId(m_texture, QSize(geo->width, geo->height), QQuickWindow::TextureCanUseAtlas));
         }
-        textureNode->texture()->bind();
+        textureProvider->texture()->bind();
         bindGLXTexture();
         return true;
     }
@@ -416,7 +436,7 @@ bool WindowThumbnail::windowToTextureGLX(WindowTextureNode *textureNode)
 #endif // HAVE_GLX
 
 #if HAVE_EGL
-bool WindowThumbnail::xcbWindowToTextureEGL(WindowTextureNode *textureNode)
+bool WindowThumbnail::xcbWindowToTextureEGL(WindowTextureProvider *textureProvider)
 {
     EGLContext context = eglGetCurrentContext();
 
@@ -434,13 +454,12 @@ bool WindowThumbnail::xcbWindowToTextureEGL(WindowTextureNode *textureNode)
             xcb_connection_t *c = QX11Info::connection();
             auto geometryCookie = xcb_get_geometry_unchecked(c, m_pixmap);
 
-            const EGLint attribs[] = {
-                EGL_IMAGE_PRESERVED_KHR, EGL_TRUE,
-                EGL_NONE
-            };
-            m_image = ((eglCreateImageKHR_func)(m_eglCreateImageKHR))(eglGetCurrentDisplay(), EGL_NO_CONTEXT,
-                      EGL_NATIVE_PIXMAP_KHR,
-                      (EGLClientBuffer)m_pixmap, attribs);
+            const EGLint attribs[] = {EGL_IMAGE_PRESERVED_KHR, EGL_TRUE, EGL_NONE};
+            m_image = ((eglCreateImageKHR_func)(m_eglCreateImageKHR))(eglGetCurrentDisplay(),
+                                                                      EGL_NO_CONTEXT,
+                                                                      EGL_NATIVE_PIXMAP_KHR,
+                                                                      (EGLClientBuffer)(uintptr_t)m_pixmap,
+                                                                      attribs);
 
             if (m_image == EGL_NO_IMAGE_KHR) {
                 qDebug() << "failed to create egl image";
@@ -454,9 +473,9 @@ bool WindowThumbnail::xcbWindowToTextureEGL(WindowTextureNode *textureNode)
                 size.setWidth(geo->width);
                 size.setHeight(geo->height);
             }
-            textureNode->reset(window()->createTextureFromId(m_texture, size, QQuickWindow::TextureCanUseAtlas));
+            textureProvider->setTexture(window()->createTextureFromId(m_texture, size, QQuickWindow::TextureCanUseAtlas));
         }
-        textureNode->texture()->bind();
+        textureProvider->texture()->bind();
         bindEGLTexture();
         return true;
     }
@@ -471,9 +490,9 @@ void WindowThumbnail::resolveEGLFunctions()
     }
     auto *context = window()->openglContext();
     QList<QByteArray> extensions = QByteArray(eglQueryString(display, EGL_EXTENSIONS)).split(' ');
-    if (extensions.contains(QByteArrayLiteral("EGL_KHR_image")) ||
-            (extensions.contains(QByteArrayLiteral("EGL_KHR_image_base")) &&
-             extensions.contains(QByteArrayLiteral("EGL_KHR_image_pixmap")))) {
+    if (extensions.contains(QByteArrayLiteral("EGL_KHR_image")) //
+        || (extensions.contains(QByteArrayLiteral("EGL_KHR_image_base")) //
+            && extensions.contains(QByteArrayLiteral("EGL_KHR_image_pixmap")))) {
         if (context->hasExtension(QByteArrayLiteral("GL_OES_EGL_image"))) {
             qDebug() << "Have EGL texture from pixmap";
             m_eglCreateImageKHR = context->getProcAddress(QByteArrayLiteral("eglCreateImageKHR"));
@@ -493,44 +512,38 @@ void WindowThumbnail::bindEGLTexture()
 
 #endif // HAVE_XCB_COMPOSITE
 
-void WindowThumbnail::windowToTexture(WindowTextureNode *textureNode)
+void WindowThumbnail::windowToTexture(WindowTextureProvider *textureProvider)
 {
-    if (!m_damaged && textureNode->texture()) {
+    if (!m_damaged && textureProvider->texture()) {
         return;
     }
 #if HAVE_XCB_COMPOSITE
-    if (!textureNode->texture()) {
-        // the texture got discarded by the scene graph, but our mapping is still valid
-        // let's discard the pixmap to have a clean state again
-        releaseResources();
-    }
     if (m_pixmap == XCB_PIXMAP_NONE) {
         m_pixmap = pixmapForWindow();
     }
     if (m_pixmap == XCB_PIXMAP_NONE) {
         // create above failed
-        iconToTexture(textureNode);
+        iconToTexture(textureProvider);
         setThumbnailAvailable(false);
         return;
     }
     bool fallbackToIcon = true;
 #if HAVE_GLX
-    fallbackToIcon = !windowToTextureGLX(textureNode);
+    fallbackToIcon = !windowToTextureGLX(textureProvider);
 #endif // HAVE_GLX
 #if HAVE_EGL
     if (fallbackToIcon) {
         // if glx succeeded fallbackToIcon is false, thus we shouldn't try egl
-        fallbackToIcon = !xcbWindowToTextureEGL(textureNode);
+        fallbackToIcon = !xcbWindowToTextureEGL(textureProvider);
     }
 #endif // HAVE_EGL
     if (fallbackToIcon) {
         // just for safety to not crash
-        iconToTexture(textureNode);
+        iconToTexture(textureProvider);
     }
     setThumbnailAvailable(!fallbackToIcon);
-    textureNode->markDirty(QSGNode::DirtyForceUpdate);
 #else
-    iconToTexture(textureNode);
+    iconToTexture(textureProvider);
 #endif
 }
 
@@ -559,8 +572,9 @@ void WindowThumbnail::resolveGLXFunctions()
     if (extensions.contains(QByteArrayLiteral("GLX_EXT_texture_from_pixmap"))) {
         m_bindTexImage = context->getProcAddress(QByteArrayLiteral("glXBindTexImageEXT"));
         m_releaseTexImage = context->getProcAddress(QByteArrayLiteral("glXReleaseTexImageEXT"));
-    } else
+    } else {
         qWarning() << "couldn't resolve GLX_EXT_texture_from_pixmap functions";
+    }
     m_openGLFunctionsResolved = true;
 }
 
@@ -572,20 +586,18 @@ void WindowThumbnail::bindGLXTexture()
     resetDamaged();
 }
 
-struct FbConfigInfo
-{
+struct FbConfigInfo {
     GLXFBConfig fbConfig;
     int textureFormat;
 };
 
-struct GlxGlobalData
-{
-    GlxGlobalData() {
-	xcb_connection_t * const conn = QX11Info::connection();
+struct GlxGlobalData {
+    GlxGlobalData()
+    {
+        xcb_connection_t *const conn = QX11Info::connection();
 
         // Fetch the render pict formats
-        reply = xcb_render_query_pict_formats_reply(conn,
-                        xcb_render_query_pict_formats_unchecked(conn), nullptr);
+        reply = xcb_render_query_pict_formats_reply(conn, xcb_render_query_pict_formats_unchecked(conn), nullptr);
 
         // Init the visual ID -> format ID hash table
         for (auto screens = xcb_render_query_pict_formats_screens_iterator(reply); screens.rem; xcb_render_pictscreen_next(&screens)) {
@@ -593,8 +605,9 @@ struct GlxGlobalData
                 const xcb_render_pictvisual_t *visuals = xcb_render_pictdepth_visuals(depths.data);
                 const int len = xcb_render_pictdepth_visuals_length(depths.data);
 
-                for (int i = 0; i < len; i++)
+                for (int i = 0; i < len; i++) {
                     visualPictFormatHash.insert(visuals[i].visual, visuals[i].format);
+                }
             }
         }
 
@@ -603,8 +616,9 @@ struct GlxGlobalData
         const int len = xcb_render_query_pict_formats_formats_length(reply);
 
         for (int i = 0; i < len; i++) {
-            if (formats[i].type == XCB_RENDER_PICT_TYPE_DIRECT)
+            if (formats[i].type == XCB_RENDER_PICT_TYPE_DIRECT) {
                 formatInfoHash.insert(formats[i].id, &formats[i].direct);
+            }
         }
 
         // Init the visual ID -> depth hash table
@@ -615,13 +629,15 @@ struct GlxGlobalData
                 const int len = xcb_depth_visuals_length(depth.data);
                 const xcb_visualtype_t *visuals = xcb_depth_visuals(depth.data);
 
-                for (int i = 0; i < len; i++)
+                for (int i = 0; i < len; i++) {
                     visualDepthHash.insert(visuals[i].visual_id, depth.data->depth);
+                }
             }
         }
     }
 
-    ~GlxGlobalData() {
+    ~GlxGlobalData()
+    {
         qDeleteAll(visualFbConfigHash);
         std::free(reply);
     }
@@ -663,31 +679,42 @@ FbConfigInfo *getConfig(xcb_visualid_t visual)
         return nullptr;
     }
 
-    const int red_bits   = qPopulationCount(direct->red_mask);
+    const int red_bits = qPopulationCount(direct->red_mask);
     const int green_bits = qPopulationCount(direct->green_mask);
-    const int blue_bits  = qPopulationCount(direct->blue_mask);
+    const int blue_bits = qPopulationCount(direct->blue_mask);
     const int alpha_bits = qPopulationCount(direct->alpha_mask);
 
     const int depth = visualDepth(visual);
 
     const auto rgb_sizes = std::tie(red_bits, green_bits, blue_bits);
 
-    const int attribs[] = {
-        GLX_RENDER_TYPE,                  GLX_RGBA_BIT,
-        GLX_DRAWABLE_TYPE,                GLX_WINDOW_BIT | GLX_PIXMAP_BIT,
-        GLX_X_VISUAL_TYPE,                GLX_TRUE_COLOR,
-        GLX_X_RENDERABLE,                 True,
-        GLX_CONFIG_CAVEAT,                int(GLX_DONT_CARE), // The ARGB32 visual is marked non-conformant in Catalyst
-        GLX_FRAMEBUFFER_SRGB_CAPABLE_EXT, int(GLX_DONT_CARE),
-        GLX_BUFFER_SIZE,                  red_bits + green_bits + blue_bits + alpha_bits,
-        GLX_RED_SIZE,                     red_bits,
-        GLX_GREEN_SIZE,                   green_bits,
-        GLX_BLUE_SIZE,                    blue_bits,
-        GLX_ALPHA_SIZE,                   alpha_bits,
-        GLX_STENCIL_SIZE,                 0,
-        GLX_DEPTH_SIZE,                   0,
-        0
-    };
+    const int attribs[] = {GLX_RENDER_TYPE,
+                           GLX_RGBA_BIT,
+                           GLX_DRAWABLE_TYPE,
+                           GLX_WINDOW_BIT | GLX_PIXMAP_BIT,
+                           GLX_X_VISUAL_TYPE,
+                           GLX_TRUE_COLOR,
+                           GLX_X_RENDERABLE,
+                           True,
+                           GLX_CONFIG_CAVEAT,
+                           int(GLX_DONT_CARE), // The ARGB32 visual is marked non-conformant in Catalyst
+                           GLX_FRAMEBUFFER_SRGB_CAPABLE_EXT,
+                           int(GLX_DONT_CARE),
+                           GLX_BUFFER_SIZE,
+                           red_bits + green_bits + blue_bits + alpha_bits,
+                           GLX_RED_SIZE,
+                           red_bits,
+                           GLX_GREEN_SIZE,
+                           green_bits,
+                           GLX_BLUE_SIZE,
+                           blue_bits,
+                           GLX_ALPHA_SIZE,
+                           alpha_bits,
+                           GLX_STENCIL_SIZE,
+                           0,
+                           GLX_DEPTH_SIZE,
+                           0,
+                           0};
 
     if (QByteArray((char *)glGetString(GL_RENDERER)).contains("llvmpipe")) {
         return nullptr;
@@ -709,55 +736,67 @@ FbConfigInfo *getConfig(xcb_visualid_t visual)
     QList<FBConfig> candidates;
 
     for (int i = 0; i < count; i++) {
-        int red, green, blue;
-        glXGetFBConfigAttrib(dpy, configs[i], GLX_RED_SIZE,   &red);
+        int red;
+        int green;
+        int blue;
+        glXGetFBConfigAttrib(dpy, configs[i], GLX_RED_SIZE, &red);
         glXGetFBConfigAttrib(dpy, configs[i], GLX_GREEN_SIZE, &green);
-        glXGetFBConfigAttrib(dpy, configs[i], GLX_BLUE_SIZE,  &blue);
+        glXGetFBConfigAttrib(dpy, configs[i], GLX_BLUE_SIZE, &blue);
 
-        if (std::tie(red, green, blue) != rgb_sizes)
+        if (std::tie(red, green, blue) != rgb_sizes) {
             continue;
+        }
 
         xcb_visualid_t visual;
-        glXGetFBConfigAttrib(dpy, configs[i], GLX_VISUAL_ID, (int *) &visual);
+        glXGetFBConfigAttrib(dpy, configs[i], GLX_VISUAL_ID, (int *)&visual);
 
-        if (visualDepth(visual) != depth)
+        if (visualDepth(visual) != depth) {
             continue;
+        }
 
-        int bind_rgb, bind_rgba;
+        int bind_rgb;
+        int bind_rgba;
         glXGetFBConfigAttrib(dpy, configs[i], GLX_BIND_TO_TEXTURE_RGBA_EXT, &bind_rgba);
-        glXGetFBConfigAttrib(dpy, configs[i], GLX_BIND_TO_TEXTURE_RGB_EXT,  &bind_rgb);
+        glXGetFBConfigAttrib(dpy, configs[i], GLX_BIND_TO_TEXTURE_RGB_EXT, &bind_rgb);
 
-        if (!bind_rgb && !bind_rgba)
+        if (!bind_rgb && !bind_rgba) {
             continue;
+        }
 
         int texture_targets;
         glXGetFBConfigAttrib(dpy, configs[i], GLX_BIND_TO_TEXTURE_TARGETS_EXT, &texture_targets);
 
-        if ((texture_targets & GLX_TEXTURE_2D_BIT_EXT) == 0)
+        if ((texture_targets & GLX_TEXTURE_2D_BIT_EXT) == 0) {
             continue;
+        }
 
-        int depth, stencil;
-        glXGetFBConfigAttrib(dpy, configs[i], GLX_DEPTH_SIZE,   &depth);
+        int depth;
+        int stencil;
+        glXGetFBConfigAttrib(dpy, configs[i], GLX_DEPTH_SIZE, &depth);
         glXGetFBConfigAttrib(dpy, configs[i], GLX_STENCIL_SIZE, &stencil);
 
         int texture_format;
-        if (alpha_bits)
+        if (alpha_bits) {
             texture_format = bind_rgba ? GLX_TEXTURE_FORMAT_RGBA_EXT : GLX_TEXTURE_FORMAT_RGB_EXT;
-        else
+        } else {
             texture_format = bind_rgb ? GLX_TEXTURE_FORMAT_RGB_EXT : GLX_TEXTURE_FORMAT_RGBA_EXT;
+        }
 
         candidates.append(FBConfig{configs[i], depth, stencil, texture_format});
     }
 
-    if (count > 0)
+    if (count > 0) {
         XFree(configs);
+    }
 
     std::stable_sort(candidates.begin(), candidates.end(), [](const FBConfig &left, const FBConfig &right) {
-        if (left.depth < right.depth)
+        if (left.depth < right.depth) {
             return true;
+        }
 
-        if (left.stencil < right.stencil)
+        if (left.stencil < right.stencil) {
             return true;
+        }
 
         return false;
     });
@@ -768,11 +807,10 @@ FbConfigInfo *getConfig(xcb_visualid_t visual)
         const FBConfig &candidate = candidates.front();
 
         info = new FbConfigInfo;
-        info->fbConfig      = candidate.config;
+        info->fbConfig = candidate.config;
         info->textureFormat = candidate.format;
     }
 
-
     return info;
 }
 
@@ -801,12 +839,16 @@ bool WindowThumbnail::loadGLXTexture()
 
     glGenTextures(1, &m_texture);
 
+    /* clang-format off */
     const int attrs[] = {
-        GLX_TEXTURE_FORMAT_EXT, info->textureFormat,
-        GLX_MIPMAP_TEXTURE_EXT, false,
-        GLX_TEXTURE_TARGET_EXT, GLX_TEXTURE_2D_EXT,
-        XCB_NONE
-    };
+        GLX_TEXTURE_FORMAT_EXT,
+        info->textureFormat,
+        GLX_MIPMAP_TEXTURE_EXT,
+        false,
+        GLX_TEXTURE_TARGET_EXT,
+        GLX_TEXTURE_2D_EXT,
+        XCB_NONE};
+    /* clang-format on */
 
     m_glxPixmap = glXCreatePixmap(QX11Info::display(), info->fbConfig, m_pixmap, attrs);
 
@@ -891,13 +933,11 @@ bool WindowThumbnail::startRedirecting()
 #endif
 }
 
-
-
 void WindowThumbnail::setThumbnailAvailable(bool thumbnailAvailable)
 {
     if (m_thumbnailAvailable != thumbnailAvailable) {
         m_thumbnailAvailable = thumbnailAvailable;
-        emit thumbnailAvailableChanged();
+        Q_EMIT thumbnailAvailableChanged();
     }
 }
 
@@ -913,4 +953,25 @@ void WindowThumbnail::sceneVisibilityChanged(bool visible)
     }
 }
 
+bool WindowThumbnail::isTextureProvider() const
+{
+    return true;
+}
+
+QSGTextureProvider *WindowThumbnail::textureProvider() const
+{
+    // When Item::layer::enabled == true, QQuickItem will be a texture
+    // provider. In this case we should prefer to return the layer rather
+    // than our texture
+    if (QQuickItem::isTextureProvider()) {
+        return QQuickItem::textureProvider();
+    }
+
+    if (!m_textureProvider) {
+        m_textureProvider = new WindowTextureProvider();
+    }
+
+    return m_textureProvider;
+}
+
 } // namespace
