@@ -769,8 +769,7 @@ void Applet::setGlobalShortcut(const QKeySequence &shortcut)
 
     d->activationAction->setShortcut(shortcut);
     d->globalShortcutEnabled = true;
-    QList<QKeySequence> seqs;
-    seqs << shortcut;
+    QList<QKeySequence> seqs{shortcut};
     KGlobalAccel::self()->setShortcut(d->activationAction, seqs, KGlobalAccel::NoAutoloading);
     d->globalShortcutChanged();
 }
@@ -878,7 +877,7 @@ Applet *Applet::loadPlasmoid(const QString &path, uint appletId)
     if (md.isValid()) {
         QStringList types = md.serviceTypes();
 
-        if (types.contains(QLatin1String("Plasma/Containment"))) {
+        if (types.contains(QLatin1String("Plasma/Containment")) || md.rawData().contains(QStringLiteral("X-Plasma-ContainmentType"))) {
             return new Containment(md, appletId);
         } else {
             return new Applet(md, nullptr, appletId);
