@@ -37,6 +37,16 @@
 
 namespace Plasma
 {
+Containment::Containment(QObject *parentObject, const KPluginMetaData &data, const QVariantList &args)
+    : Applet(parentObject, data, args)
+    , d(new ContainmentPrivate(this))
+{
+    // WARNING: do not access config() OR globalConfig() in this method!
+    //          that requires a scene, which is not available at this point
+    setHasConfigurationInterface(true);
+}
+
+#if PLASMA_BUILD_DEPRECATED_SINCE(5, 86)
 Containment::Containment(QObject *parent, const QString &serviceId, uint containmentId)
     : Applet(parent, serviceId, containmentId)
     , d(new ContainmentPrivate(this))
@@ -64,6 +74,7 @@ Containment::Containment(const KPluginMetaData &md, uint appletId)
     //          that requires a scene, which is not available at this point
     setHasConfigurationInterface(true);
 }
+#endif
 
 Containment::~Containment()
 {
@@ -107,7 +118,7 @@ void Containment::init()
     QAction *configAction = actions()->action(QStringLiteral("configure"));
     if (configAction) {
         if (d->type == Types::PanelContainment || d->type == Types::CustomPanelContainment) {
-            configAction->setText(i18nc("%1 is the name of the containment", "Edit %1...", title()));
+            configAction->setText(i18n("Enter Edit Mode"));
             configAction->setIcon(QIcon::fromTheme(QStringLiteral("document-edit")));
         } else {
             configAction->setText(i18nc("%1 is the name of the applet", "Configure %1...", title()));
@@ -205,15 +216,7 @@ void Containment::restore(KConfigGroup &group)
             }
         }
     }
-
-    /*
-    #ifndef NDEBUG
-    // qCDebug(LOG_PLASMA) << "Containment" << id() <<
-    #endif
-                "screen" << screen() <<
-                "geometry is" << geometry() <<
-                "config entries" << group.entryMap();
-    */
+    Applet::restore(group);
 }
 
 void Containment::save(KConfigGroup &g) const
@@ -244,7 +247,7 @@ void Containment::save(KConfigGroup &g) const
 void Containment::saveContents(KConfigGroup &group) const
 {
     KConfigGroup applets(&group, "Applets");
-    for (const Applet *applet : qAsConst(d->applets)) {
+    for (const Applet *applet : std::as_const(d->applets)) {
         KConfigGroup appletConfig(&applets, QString::number(applet->id()));
         applet->save(appletConfig);
     }
@@ -261,7 +264,7 @@ void Containment::restoreContents(KConfigGroup &group)
     // Sort the applet configs in order of geometry to ensure that applets
     // are added from left to right or top to bottom for a panel containment
     QList<KConfigGroup> appletConfigs;
-    for (const QString &appletGroup : qAsConst(groups)) {
+    for (const QString &appletGroup : std::as_const(groups)) {
         // qCDebug(LOG_PLASMA) << "reading from applet group" << appletGroup;
         KConfigGroup appletConfig(&applets, appletGroup);
         appletConfigs.append(appletConfig);
@@ -358,7 +361,7 @@ void Containment::setLocation(Types::Location location)
 
     d->location = location;
 
-    for (Applet *applet : qAsConst(d->applets)) {
+    for (Applet *applet : std::as_const(d->applets)) {
         applet->updateConstraints(Plasma::Types::LocationConstraint);
     }
 
