@@ -7,22 +7,21 @@
 #include "containmentactions.h"
 #include "containment.h"
 
-#include "private/containmentactions_p.h"
 #include "private/containment_p.h"
+#include "private/containmentactions_p.h"
 
+#include <QContextMenuEvent>
+#include <QDebug>
 #include <QMetaEnum>
 #include <QMouseEvent>
 #include <QWheelEvent>
-#include <QContextMenuEvent>
 
-#include <QDebug>
 #include <KLocalizedString>
 
 #include "version.h"
 
 namespace Plasma
 {
-
 ContainmentActions::ContainmentActions(QObject *parentObject)
     : d(new ContainmentActionsPrivate({}, this))
 {
@@ -48,10 +47,12 @@ ContainmentActions::~ContainmentActions()
     delete d;
 }
 
+#if PLASMA_BUILD_DEPRECATED_SINCE(5, 67)
 KPluginInfo ContainmentActions::pluginInfo() const
 {
     return KPluginInfo(d->containmentActionsDescription);
 }
+#endif
 
 KPluginMetaData ContainmentActions::metadata() const
 {
@@ -84,17 +85,17 @@ QWidget *ContainmentActions::createConfigurationInterface(QWidget *parent)
 
 void ContainmentActions::configurationAccepted()
 {
-    //do nothing by default
+    // do nothing by default
 }
 
 void ContainmentActions::performNextAction()
 {
-    //do nothing by default, implement in subclasses
+    // do nothing by default, implement in subclasses
 }
 
 void ContainmentActions::performPreviousAction()
 {
-    //do nothing by default, implement in subclasses
+    // do nothing by default, implement in subclasses
 }
 
 QList<QAction *> ContainmentActions::contextualActions()
@@ -107,13 +108,19 @@ QString ContainmentActions::eventToString(QEvent *event)
     QString trigger;
     Qt::KeyboardModifiers modifiers;
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+    const auto &mo = QObject::staticQtMetaObject;
+#else
+    const auto &mo = Qt::staticMetaObject;
+#endif
+
     switch (event->type()) {
     case QEvent::MouseButtonPress:
     case QEvent::MouseButtonRelease:
     case QEvent::MouseButtonDblClick: {
         QMouseEvent *e = static_cast<QMouseEvent *>(event);
-        int m = QObject::staticQtMetaObject.indexOfEnumerator("MouseButtons");
-        QMetaEnum mouse = QObject::staticQtMetaObject.enumerator(m);
+        int m = mo.indexOfEnumerator("MouseButtons");
+        QMetaEnum mouse = mo.enumerator(m);
         trigger += QString::fromLatin1(mouse.valueToKey(e->button()));
         modifiers = e->modifiers();
         break;
@@ -128,8 +135,8 @@ QString ContainmentActions::eventToString(QEvent *event)
         break;
     }
     case QEvent::ContextMenu: {
-        int m = QObject::staticQtMetaObject.indexOfEnumerator("MouseButtons");
-        QMetaEnum mouse = QObject::staticQtMetaObject.enumerator(m);
+        int m = mo.indexOfEnumerator("MouseButtons");
+        QMetaEnum mouse = mo.enumerator(m);
         trigger = QString::fromLatin1(mouse.valueToKey(Qt::RightButton));
         modifiers = Qt::NoModifier;
         break;
@@ -138,8 +145,8 @@ QString ContainmentActions::eventToString(QEvent *event)
         return QString();
     }
 
-    int k = QObject::staticQtMetaObject.indexOfEnumerator("KeyboardModifiers");
-    QMetaEnum kbd = QObject::staticQtMetaObject.enumerator(k);
+    int k = mo.indexOfEnumerator("KeyboardModifiers");
+    QMetaEnum kbd = mo.enumerator(k);
     trigger += QLatin1Char(';') + QString::fromLatin1(kbd.valueToKeys(modifiers));
 
     return trigger;
