@@ -9,9 +9,11 @@
 #include <QPointer>
 #include <QStandardPaths>
 
+#include <KLazyLocalizedString>
 #include <KService>
 #include <KServiceTypeTrader>
 #include <QDebug>
+#include <QRegExp>
 #include <kdeclarative/kdeclarative.h>
 #include <kpackage/packageloader.h>
 
@@ -33,6 +35,14 @@
 
 namespace Plasma
 {
+inline bool isContainmentMetaData(const KPluginMetaData &md)
+{
+    return md.rawData().contains(QStringLiteral("X-Plasma-ContainmentType"))
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+        || md.serviceTypes().contains(QLatin1String("Plasma/Containment"))
+#endif
+        ;
+}
 static PluginLoader *s_pluginLoader = nullptr;
 
 class PluginLoaderPrivate
@@ -91,28 +101,28 @@ QSet<QString> PluginLoaderPrivate::knownCategories()
     // strings for translation
     QSet<QString> categories = s_customCategories;
     /* clang-format off */
-    categories << QStringLiteral(I18N_NOOP("Accessibility")).toLower()
-               << QStringLiteral(I18N_NOOP("Application Launchers")).toLower()
-               << QStringLiteral(I18N_NOOP("Astronomy")).toLower()
-               << QStringLiteral(I18N_NOOP("Date and Time")).toLower()
-               << QStringLiteral(I18N_NOOP("Development Tools")).toLower()
-               << QStringLiteral(I18N_NOOP("Education")).toLower()
-               << QStringLiteral(I18N_NOOP("Environment and Weather")).toLower()
-               << QStringLiteral(I18N_NOOP("Examples")).toLower()
-               << QStringLiteral(I18N_NOOP("File System")).toLower()
-               << QStringLiteral(I18N_NOOP("Fun and Games")).toLower()
-               << QStringLiteral(I18N_NOOP("Graphics")).toLower()
-               << QStringLiteral(I18N_NOOP("Language")).toLower()
-               << QStringLiteral(I18N_NOOP("Mapping")).toLower()
-               << QStringLiteral(I18N_NOOP("Miscellaneous")).toLower()
-               << QStringLiteral(I18N_NOOP("Multimedia")).toLower()
-               << QStringLiteral(I18N_NOOP("Online Services")).toLower()
-               << QStringLiteral(I18N_NOOP("Productivity")).toLower()
-               << QStringLiteral(I18N_NOOP("System Information")).toLower()
-               << QStringLiteral(I18N_NOOP("Utilities")).toLower()
-               << QStringLiteral(I18N_NOOP("Windows and Tasks")).toLower()
-               << QStringLiteral(I18N_NOOP("Clipboard")).toLower()
-               << QStringLiteral(I18N_NOOP("Tasks")).toLower();
+    categories << kli18n("Accessibility").toString().toLower()
+               << kli18n("Application Launchers").toString().toLower()
+               << kli18n("Astronomy").toString().toLower()
+               << kli18n("Date and Time").toString().toLower()
+               << kli18n("Development Tools").toString().toLower()
+               << kli18n("Education").toString().toLower()
+               << kli18n("Environment and Weather").toString().toLower()
+               << kli18n("Examples").toString().toLower()
+               << kli18n("File System").toString().toLower()
+               << kli18n("Fun and Games").toString().toLower()
+               << kli18n("Graphics").toString().toLower()
+               << kli18n("Language").toString().toLower()
+               << kli18n("Mapping").toString().toLower()
+               << kli18n("Miscellaneous").toString().toLower()
+               << kli18n("Multimedia").toString().toLower()
+               << kli18n("Online Services").toString().toLower()
+               << kli18n("Productivity").toString().toLower()
+               << kli18n("System Information").toString().toLower()
+               << kli18n("Utilities").toString().toLower()
+               << kli18n("Windows and Tasks").toString().toLower()
+               << kli18n("Clipboard").toString().toLower()
+               << kli18n("Tasks").toString().toLower();
     /* clang-format on */
     return categories;
 }
@@ -202,7 +212,7 @@ Applet *PluginLoader::loadApplet(const QString &name, uint appletId, const QVari
         QVariantList allArgs;
         allArgs << QVariant::fromValue(p) << p.metadata().fileName() << appletId << args;
 
-        if (p.metadata().serviceTypes().contains(QLatin1String("Plasma/Containment"))) {
+        if (isContainmentMetaData(p.metadata())) {
             applet = new Containment(nullptr, p.metadata(), allArgs);
         } else {
             applet = new Applet(nullptr, p.metadata(), allArgs);
@@ -655,11 +665,7 @@ KPluginInfo::List PluginLoader::listContainments(const QString &category, const
 QList<KPluginMetaData> PluginLoader::listContainmentsMetaData(std::function<bool(const KPluginMetaData &)> filter)
 {
     auto ownFilter = [filter](const KPluginMetaData &md) -> bool {
-        if (!md.serviceTypes().contains(QLatin1String("Plasma/Containment"))) {
-            return false;
-        }
-
-        return filter(md);
+        return isContainmentMetaData(md) && filter(md);
     };
 
     return KPackage::PackageLoader::self()->findPackages(QStringLiteral("Plasma/Applet"), QString(), ownFilter);
@@ -679,7 +685,7 @@ KPluginInfo::List PluginLoader::listContainmentsOfType(const QString &type, cons
 {
     KConfigGroup group(KSharedConfig::openConfig(), "General");
     auto filter = [&type, &category, &parentApp](const KPluginMetaData &md) -> bool {
-        if (!md.serviceTypes().contains(QLatin1String("Plasma/Containment"))) {
+        if (isContainmentMetaData(md)) {
             return false;
         }
         if (!parentApp.isEmpty() && md.value(QStringLiteral("X-KDE-ParentApp")) != parentApp) {
@@ -705,8 +711,7 @@ KPluginInfo::List PluginLoader::listContainmentsOfType(const QString &type, cons
 KPluginInfo::List PluginLoader::listContainmentsForMimeType(const QString &mimeType)
 {
     auto filter = [&mimeType](const KPluginMetaData &md) -> bool {
-        return md.serviceTypes().contains(QLatin1String("Plasma/Containment"))
-            && md.value(QStringLiteral("X-Plasma-DropMimeTypes"), QStringList()).contains(mimeType);
+        return isContainmentMetaData(md) && md.value(QStringLiteral("X-Plasma-DropMimeTypes"), QStringList()).contains(mimeType);
     };
 
     return KPluginInfo::fromMetaData(KPackage::PackageLoader::self()->findPackages(QStringLiteral("Plasma/Applet"), QString(), filter).toVector());
