@@ -7,18 +7,18 @@
 #ifndef PLASMA_SVG_P_H
 #define PLASMA_SVG_P_H
 
+#include "svg.h"
+
+#include <QExplicitlySharedDataPointer>
 #include <QHash>
+#include <QObject>
 #include <QPointer>
 #include <QSharedData>
 #include <QSvgRenderer>
-#include <QExplicitlySharedDataPointer>
-#include <QObject>
 
 namespace Plasma
 {
 
-class Svg;
-
 class SharedSvgRenderer : public QSvgRenderer, public QSharedData
 {
     Q_OBJECT
@@ -26,23 +26,18 @@ public:
     typedef QExplicitlySharedDataPointer<SharedSvgRenderer> Ptr;
 
     explicit SharedSvgRenderer(QObject *parent = nullptr);
-    SharedSvgRenderer(
-        const QString &filename,
-        const QString &styleSheet,
-        QHash<QString, QRectF> &interestingElements,
-        QObject *parent = nullptr);
+    SharedSvgRenderer(const QString &filename, const QString &styleSheet, QHash<QString, QRectF> &interestingElements, QObject *parent = nullptr);
 
-    SharedSvgRenderer(
-        const QByteArray &contents,
-        const QString &styleSheet,
-        QHash<QString, QRectF> &interestingElements,
-        QObject *parent = nullptr);
+    SharedSvgRenderer(const QByteArray &contents, const QString &styleSheet, QHash<QString, QRectF> &interestingElements, QObject *parent = nullptr);
+
+    void reload();
 
 private:
-    bool load(
-        const QByteArray &contents,
-        const QString &styleSheet,
-        QHash<QString, QRectF> &interestingElements);
+    bool load(const QByteArray &contents, const QString &styleSheet, QHash<QString, QRectF> &interestingElements);
+
+    QString m_filename;
+    QString m_styleSheet;
+    QHash<QString, QRectF> m_interestingElements;
 };
 
 class SvgPrivate
@@ -57,17 +52,17 @@ public:
         double devicePixelRatio;
         double scaleFactor;
         int colorGroup;
-        uint extraFlags; //Not used here, used for enabledborders in FrameSvg
+        uint extraFlags; // Not used here, used for enabledborders in FrameSvg
         uint lastModified;
     };
 
     SvgPrivate(Svg *svg);
     ~SvgPrivate();
 
-    //This function is meant for the rects cache
+    // This function is meant for the rects cache
     CacheId cacheId(const QString &elementId) const;
 
-    //This function is meant for the pixmap cache
+    // This function is meant for the pixmap cache
     QString cachePath(const QString &path, const QSize &size) const;
 
     bool setImagePath(const QString &imagePath);
@@ -85,13 +80,13 @@ public:
 
     void checkColorHints();
 
-    //Following two are utility functions to snap rendered elements to the pixel grid
-    //to and from are always 0 <= val <= 1
+    // Following two are utility functions to snap rendered elements to the pixel grid
+    // to and from are always 0 <= val <= 1
     qreal closestDistance(qreal to, qreal from);
 
     QRectF makeUniform(const QRectF &orig, const QRectF &dst);
 
-    //Slots
+    // Slots
     void themeChanged();
     void colorsChanged();
 
@@ -122,8 +117,8 @@ public:
     bool themeFailed : 1;
 };
 
-
-class SvgRectsCache : public QObject {
+class SvgRectsCache : public QObject
+{
     Q_OBJECT
 public:
     SvgRectsCache(QObject *parent = nullptr);
@@ -136,9 +131,8 @@ public:
     bool findElementRect(SvgPrivate::CacheId cacheId, QRectF &rect);
     bool findElementRect(uint id, const QString &filePath, QRectF &rect);
 
-    void loadImageFromCache(const QString &path, uint lastModified);
+    bool loadImageFromCache(const QString &path, uint lastModified);
     void dropImageFromCache(const QString &path);
-    void expireCache(const QString &path);
 
     void setNaturalSize(const QString &path, qreal scaleFactor, const QSizeF &size);
     QSizeF naturalSize(const QString &path, qreal scaleFactor);
@@ -151,15 +145,20 @@ public:
 
     QStringList cachedKeysForPath(const QString &path) const;
 
+    unsigned int lastModifiedTimeFromCache(const QString &filePath);
+
     void updateLastModified(const QString &filePath, unsigned int lastModified);
 
     static const uint s_seed;
 
+Q_SIGNALS:
+    void lastModifiedChanged(const QString &filePath, unsigned int lastModified);
+
 private:
     QTimer *m_configSyncTimer = nullptr;
     QString m_iconThemePath;
     KSharedConfigPtr m_svgElementsCache;
-    /* 
+    /*
      * We are indexing in the hash cache ids by their "digested" uint out of qHash(CacheId)
      * because we need to serialize it and unserialize it to a config file,
      * which is more efficient to do that with the uint directly rather than a CacheId struct serialization
@@ -167,11 +166,10 @@ private:
     QHash<uint, QRectF> m_localRectCache;
     QHash<QString, QSet<unsigned int>> m_invalidElements;
     QHash<QString, QList<QSize>> m_sizeHintsForId;
+    QHash<QString, unsigned int> m_lastModifiedTimes;
 };
-
 }
 
 uint qHash(const Plasma::SvgPrivate::CacheId &id, uint seed = 0);
 
 #endif
-
