@@ -8,8 +8,8 @@
 #ifndef PLASMA_THEME_H
 #define PLASMA_THEME_H
 
-#include <QGuiApplication>
 #include <QFont>
+#include <QGuiApplication>
 #include <QObject>
 
 #include <KPluginInfo>
@@ -21,7 +21,6 @@ class KPluginMetaData;
 
 namespace Plasma
 {
-
 class ThemePrivate;
 class SvgPrivate;
 
@@ -47,7 +46,7 @@ class PLASMA_EXPORT Theme : public QObject
     Q_PROPERTY(bool useGlobalSettings READ useGlobalSettings NOTIFY themeChanged)
     Q_PROPERTY(QString wallpaperPath READ wallpaperPath NOTIFY themeChanged)
 
-    //fonts
+    // fonts
     Q_PROPERTY(QFont defaultFont READ defaultFont NOTIFY defaultFontChanged)
     Q_PROPERTY(QFont smallestFont READ smallestFont NOTIFY smallestFontChanged)
 
@@ -66,11 +65,11 @@ public:
         FocusColor = 4, /**< color for focus effect on view */
         LinkColor = 5, /**< color for clickable links */
         VisitedLinkColor = 6, /**< color visited clickable links */
-        HighlightedTextColor = 7,/**< color contrasting with HighlightColor, to be used for instance with */
+        HighlightedTextColor = 7, /**< color contrasting with HighlightColor, to be used for instance with */
         PositiveTextColor = 8, /**< color of foreground objects with a "positive message" connotation (usually green) */
         NeutralTextColor = 9, /**< color of foreground objects with a "neutral message" connotation (usually yellow) */
         NegativeTextColor = 10, /**< color of foreground objects with a "negative message" connotation (usually red) */
-        DisabledTextColor = 11 /**< color of disabled text @since 5.64 */
+        DisabledTextColor = 11, /**< color of disabled text @since 5.64 */
     };
 
     enum ColorGroup {
@@ -78,7 +77,8 @@ public:
         ButtonColorGroup = 1,
         ViewColorGroup = 2,
         ComplementaryColorGroup = 3,
-        HeaderColorGroup
+        HeaderColorGroup,
+        ToolTipColorGroup,
     };
     Q_ENUM(ColorGroup)
 
@@ -96,7 +96,7 @@ public:
      */
     explicit Theme(const QString &themeName, QObject *parent = nullptr);
 
-    ~Theme();
+    ~Theme() override;
 
     /**
      * Sets the current theme being used.
@@ -220,6 +220,10 @@ public:
      * @param lastModified if non-zero, the time stamp is also checked on the file,
      *                     and must be newer than the timestamp to be loaded
      *
+     * @note Since KF 5.75, a lastModified value of 0 is deprecated. If used, it
+     *       will now always return false. Use a proper file timestamp instead
+     *       so modification can be properly tracked.
+     *
      * @return true when pixmap was found and loaded from cache, false otherwise
      * @since 4.3
      **/
@@ -265,6 +269,7 @@ public:
      **/
     void setCacheLimit(int kbytes);
 
+#if PLASMA_ENABLE_DEPRECATED_SINCE(5, 78)
     /**
      * Tries to load the rect of a sub element from a disk cache
      *
@@ -274,6 +279,7 @@ public:
      *           if not found or if we are sure it doesn't exist it will be QRect()
      * @return true if the element was found in cache or if we are sure the element doesn't exist
      **/
+    PLASMA_DEPRECATED_VERSION(5, 78, "Rects Cache public API is deprecated")
     bool findInRectsCache(const QString &image, const QString &element, QRectF &rect) const;
 
     /**
@@ -285,6 +291,7 @@ public:
      *
      * @since 4.6
      */
+    PLASMA_DEPRECATED_VERSION(5, 78, "Rects Cache public API is deprecated")
     QStringList listCachedRectKeys(const QString &image) const;
 
     /**
@@ -294,6 +301,7 @@ public:
      * @param element sub element we want insert the rect
      * @param rect element rectangle
      **/
+    PLASMA_DEPRECATED_VERSION(5, 78, "Rects Cache public API is deprecated")
     void insertIntoRectsCache(const QString &image, const QString &element, const QRectF &rect);
 
     /**
@@ -301,6 +309,7 @@ public:
      *
      * @param image the path to the image the cache is associated with
      **/
+    PLASMA_DEPRECATED_VERSION(5, 78, "Rects Cache public API is deprecated")
     void invalidateRectsCache(const QString &image);
 
     /**
@@ -310,7 +319,9 @@ public:
      *
      * @param image the path to the image the cache is associated with
      */
+    PLASMA_DEPRECATED_VERSION(5, 78, "Rects Cache public API is deprecated")
     void releaseRectsCache(const QString &image);
+#endif
 
 #if PLASMA_ENABLE_DEPRECATED_SINCE(5, 67)
     /**
@@ -324,13 +335,6 @@ public:
     KPluginInfo pluginInfo() const;
 #endif
 
-    /**
-     * @return metadata for this theme, with information such as
-     * name, description, author, website etc
-     * @since 5.67
-     */
-    KPluginMetaData metadata() const;
-
     /**
      * @return The default application font
      * @since 5.0
@@ -361,6 +365,21 @@ public:
      */
     bool backgroundContrastEnabled() const;
 
+    /** This method allows Plasma to enable and disable the adaptive
+     * transparency option of the panel, which allows user to decide
+     * whether the panel should be always transparent, always opaque
+     * or only opaque when a window is maximized.
+     * The configuration in the metadata.desktop file of the theme
+     * could look like this (for a lighter background):
+     * \code
+     * [AdaptiveTransparency]
+     * enabled=true
+     * \endcode
+     * @return Whether or not to enable the adaptive transparency
+     * @since 5.20
+     */
+    bool adaptiveTransparencyEnabled() const;
+
     /** This method allows Plasma to set a background contrast effect
      * for a given theme, improving readability. The value is read
      * from the "contrast" key in the "ContrastEffect" group in the
@@ -415,7 +434,7 @@ public:
      * You can use it like this in QML Items:
      * \code
      * Item {
-     *     width: theme.mSize(theme.defaultFont).height
+     *     width: PlasmaCore.Theme.mSize(PlasmaCore.Theme.defaultFont).height
      *     height: width
      * }
      * \endcode
@@ -429,6 +448,8 @@ public:
 
     QString backgroundPath(const QString &image) const;
 
+    static QPalette globalPalette();
+
 Q_SIGNALS:
     /**
      * Emitted when the user changes the theme. Stylesheet usage, colors, etc. should
@@ -456,4 +477,3 @@ private:
 } // Plasma namespace
 
 #endif // multiple inclusion guard
-
