@@ -1,59 +1,45 @@
 /*
- *   Copyright 2013 Marco Martin <mart@kde.org>
- *
- *   This program is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU Library General Public License as
- *   published by the Free Software Foundation; either version 2, or
- *   (at your option) any later version.
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details
- *
- *   You should have received a copy of the GNU Library General Public
- *   License along with this program; if not, write to the
- *   Free Software Foundation, Inc.,
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
- */
+    SPDX-FileCopyrightText: 2013 Marco Martin <mart@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
-#include "private/configcategory_p.h"
 #include "configview.h"
-#include "configmodel.h"
 #include "Plasma/Applet"
 #include "Plasma/Containment"
+#include "configmodel.h"
+#include "private/configcategory_p.h"
 //#include "plasmoid/wallpaperinterface.h"
-#include "kdeclarative/configpropertymap.h"
 
 #include <QDebug>
 #include <QDir>
 #include <QQmlComponent>
-#include <QQmlEngine>
 #include <QQmlContext>
+#include <QQmlEngine>
 #include <QQuickItem>
 
 #include <KAuthorized>
-#include <klocalizedstring.h>
+#include <KLocalizedContext>
+#include <KLocalizedString>
+#include <KQuickAddons/ConfigModule>
 #include <kdeclarative/kdeclarative.h>
 #include <packageurlinterceptor.h>
-#include <KQuickAddons/ConfigModule>
 
 #include <Plasma/Corona>
 #include <Plasma/PluginLoader>
 
-//Unfortunately QWINDOWSIZE_MAX is not exported
-#define DIALOGSIZE_MAX ((1<<24)-1)
+// Unfortunately QWINDOWSIZE_MAX is not exported
+#define DIALOGSIZE_MAX ((1 << 24) - 1)
 
 namespace PlasmaQuick
 {
-
 //////////////////////////////ConfigView
 
 class ConfigViewPrivate
 {
 public:
     ConfigViewPrivate(Plasma::Applet *appl, ConfigView *view);
-    ~ConfigViewPrivate();
+    ~ConfigViewPrivate() = default;
 
     void init();
 
@@ -64,19 +50,19 @@ public:
     void mainItemLoaded();
 
     ConfigView *q;
-    QPointer <Plasma::Applet> applet;
+    QPointer<Plasma::Applet> applet;
     ConfigModel *configModel;
     ConfigModel *kcmConfigModel;
     Plasma::Corona *corona;
 
-    //Attached Layout property of mainItem, if any
-    QPointer <QObject> mainItemLayout;
+    // Attached Layout property of mainItem, if any
+    QPointer<QObject> mainItemLayout;
 };
 
 ConfigViewPrivate::ConfigViewPrivate(Plasma::Applet *appl, ConfigView *view)
-    : q(view),
-      applet(appl),
-      corona(nullptr)
+    : q(view)
+    , applet(appl)
+    , corona(nullptr)
 {
 }
 
@@ -93,21 +79,22 @@ void ConfigViewPrivate::init()
 
     applet.data()->setUserConfiguring(true);
 
-    KDeclarative::KDeclarative kdeclarative;
-    kdeclarative.setDeclarativeEngine(q->engine());
+    KLocalizedContext *localizedContextObject = new KLocalizedContext(q->engine());
     const QString rootPath = applet.data()->pluginMetaData().value(QStringLiteral("X-Plasma-RootPath"));
     if (!rootPath.isEmpty()) {
-        kdeclarative.setTranslationDomain(QStringLiteral("plasma_applet_") + rootPath);
+        localizedContextObject->setTranslationDomain(QStringLiteral("plasma_applet_") + rootPath);
     } else {
-        kdeclarative.setTranslationDomain(QStringLiteral("plasma_applet_") + applet.data()->pluginMetaData().pluginId());
+        localizedContextObject->setTranslationDomain(QStringLiteral("plasma_applet_") + applet.data()->pluginMetaData().pluginId());
     }
-    kdeclarative.setupBindings();
+    q->engine()->rootContext()->setContextObject(localizedContextObject);
 
-    //FIXME: problem on nvidia, all windows should be transparent or won't show
+    KDeclarative::KDeclarative::setupEngine(q->engine()); // ### how to make sure to do this only once per engine?
+
+    // FIXME: problem on nvidia, all windows should be transparent or won't show
     q->setColor(Qt::transparent);
     q->setTitle(i18n("%1 Settings", applet.data()->title()));
 
-    //systray case
+    // systray case
     if (!applet.data()->containment()->corona()) {
         Plasma::Applet *a = qobject_cast<Plasma::Applet *>(applet.data()->containment()->parent());
         if (a) {
@@ -128,13 +115,18 @@ void ConfigViewPrivate::init()
         PackageUrlInterceptor *interceptor = new PackageUrlInterceptor(q->engine(), pkg);
         interceptor->addAllowedPath(applet.data()->kPackage().path());
         q->engine()->setUrlInterceptor(interceptor);
+        new QQmlFileSelector(q->engine(), q->engine());
     }
 
     q->setResizeMode(QQuickView::SizeViewToRootObject);
 
-    //config model local of the applet
+    auto plasmoid = applet.data()->property("_plasma_graphicObject").value<QObject *>();
+    q->engine()->rootContext()->setContextProperties({QQmlContext::PropertyPair{QStringLiteral("plasmoid"), QVariant::fromValue(plasmoid)},
+                                                      QQmlContext::PropertyPair{QStringLiteral("configDialog"), QVariant::fromValue(q)}});
+
+    // config model local of the applet
     QQmlComponent *component = new QQmlComponent(q->engine(), applet.data()->kPackage().fileUrl("configmodel"), q);
-    QObject *object = component->beginCreate(q->engine()->rootContext());
+    QObject *object = component->create(q->engine()->rootContext());
     configModel = qobject_cast<ConfigModel *>(object);
 
     if (configModel) {
@@ -143,36 +135,38 @@ void ConfigViewPrivate::init()
         delete object;
     }
 
-    QStringList kcms = KPluginMetaData::readStringList(applet.data()->pluginMetaData().rawData(), QStringLiteral("X-Plasma-ConfigPlugins"));
+    QStringList kcms = applet.data()->pluginMetaData().value(QStringLiteral("X-Plasma-ConfigPlugins"), QStringList());
 
     // filter out non-authorized KCMs
     // KAuthorized expects KCMs with .desktop suffix, so we can't just pass everything
     // to KAuthorized::authorizeControlModules verbatim
-    kcms.erase(std::remove_if(kcms.begin(), kcms.end(), [](const QString &kcm) {
-        return !KAuthorized::authorizeControlModule(kcm + QLatin1String(".desktop"));
-    }), kcms.end());
+    kcms.erase(std::remove_if(kcms.begin(),
+                              kcms.end(),
+                              [](const QString &kcm) {
+                                  return !KAuthorized::authorizeControlModule(kcm + QLatin1String(".desktop"));
+                              }),
+               kcms.end());
 
     if (!kcms.isEmpty()) {
         if (!configModel) {
             configModel = new ConfigModel(q);
         }
 
-        foreach (const QString &kcm, kcms) {
-            KPluginLoader loader(KPluginLoader::findPlugin(QLatin1String("kcms/") + kcm));
-            KPluginMetaData md(loader.fileName());
+        for (const QString &kcm : std::as_const(kcms)) {
+            // Only look for KCMs in the "kcms_" folder where new QML KCMs live
+            // because we don't support loading QWidgets KCMs
+            KPluginMetaData md(QLatin1String("kcms/") + kcm);
 
             if (!md.isValid()) {
-                qWarning() << "Could not find" << kcm << "specified in X-Plasma-ConfigPlugins";
+                qWarning() << "Could not find" << kcm
+                           << "requested by X-Plasma-ConfigPlugins. Ensure that it exists, is a QML KCM, and lives in the 'kcms/' subdirectory.";
                 continue;
             }
 
-            configModel->appendCategory(md.iconName(), md.name(), QString(), loader.fileName());
+            configModel->appendCategory(md.iconName(), md.name(), QString(), QLatin1String("kcms/") + kcm);
         }
     }
 
-    q->engine()->rootContext()->setContextProperty(QStringLiteral("plasmoid"), applet.data()->property("_plasma_graphicObject").value<QObject *>());
-    q->engine()->rootContext()->setContextProperty(QStringLiteral("configDialog"), q);
-    component->completeCreate();
     delete component;
 }
 
@@ -180,7 +174,7 @@ void ConfigViewPrivate::updateMinimumWidth()
 {
     if (mainItemLayout) {
         q->setMinimumWidth(mainItemLayout.data()->property("minimumWidth").toInt());
-        //Sometimes setMinimumWidth doesn't actually resize: Qt bug?
+        // Sometimes setMinimumWidth doesn't actually resize: Qt bug?
 
         q->setWidth(qMax(q->width(), q->minimumWidth()));
     } else {
@@ -192,7 +186,7 @@ void ConfigViewPrivate::updateMinimumHeight()
 {
     if (mainItemLayout) {
         q->setMinimumHeight(mainItemLayout.data()->property("minimumHeight").toInt());
-        //Sometimes setMinimumHeight doesn't actually resize: Qt bug?
+        // Sometimes setMinimumHeight doesn't actually resize: Qt bug?
 
         q->setHeight(qMax(q->height(), q->minimumHeight()));
     } else {
@@ -238,18 +232,17 @@ void ConfigViewPrivate::mainItemLoaded()
         q->resize(cg.readEntry("DialogWidth", q->width()), cg.readEntry("DialogHeight", q->height()));
     }
 
-    //Extract the representation's Layout, if any
+    // Extract the representation's Layout, if any
     QObject *layout = nullptr;
 
-    //Search a child that has the needed Layout properties
-    //HACK: here we are not type safe, but is the only way to access to a pointer of Layout
-    foreach (QObject *child, q->rootObject()->children()) {
-        //find for the needed property of Layout: minimum/maximum/preferred sizes and fillWidth/fillHeight
-        if (child->property("minimumWidth").isValid() && child->property("minimumHeight").isValid() &&
-                child->property("preferredWidth").isValid() && child->property("preferredHeight").isValid() &&
-                child->property("maximumWidth").isValid() && child->property("maximumHeight").isValid() &&
-                child->property("fillWidth").isValid() && child->property("fillHeight").isValid()
-            ) {
+    // Search a child that has the needed Layout properties
+    // HACK: here we are not type safe, but is the only way to access to a pointer of Layout
+    const auto children = q->rootObject()->children();
+    for (QObject *child : children) {
+        // find for the needed property of Layout: minimum/maximum/preferred sizes and fillWidth/fillHeight
+        if (child->property("minimumWidth").isValid() && child->property("minimumHeight").isValid() && child->property("preferredWidth").isValid()
+            && child->property("preferredHeight").isValid() && child->property("maximumWidth").isValid() && child->property("maximumHeight").isValid()
+            && child->property("fillWidth").isValid() && child->property("fillHeight").isValid()) {
             layout = child;
             break;
         }
@@ -269,10 +262,9 @@ void ConfigViewPrivate::mainItemLoaded()
     }
 }
 
-
 ConfigView::ConfigView(Plasma::Applet *applet, QWindow *parent)
-    : QQuickView(parent),
-      d(new ConfigViewPrivate(applet, this))
+    : QQuickView(parent)
+    , d(new ConfigViewPrivate(applet, this))
 {
     setIcon(QIcon::fromTheme(QStringLiteral("configure")));
     qmlRegisterType<ConfigModel>("org.kde.plasma.configuration", 2, 0, "ConfigModel");
@@ -327,10 +319,10 @@ void ConfigView::setAppletGlobalShortcut(const QString &shortcut)
     }
 
     d->applet.data()->setGlobalShortcut(shortcut);
-    emit appletGlobalShortcutChanged();
+    Q_EMIT appletGlobalShortcutChanged();
 }
 
-//To emulate Qt::WA_DeleteOnClose that QWindow doesn't have
+// To emulate Qt::WA_DeleteOnClose that QWindow doesn't have
 void ConfigView::hideEvent(QHideEvent *ev)
 {
     QQuickWindow::hideEvent(ev);
