@@ -1,23 +1,10 @@
 /*
- *   Copyright 2008 Chani Armitage <chani@kde.org>
- *   Copyright 2008, 2009 Aaron Seigo <aseigo@kde.org>
- *   Copyright 2010 Marco Martin <mart@kde.org>
- *
- *   This program is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU Library General Public License as
- *   published by the Free Software Foundation; either version 2, or
- *   (at your option) any later version.
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details
- *
- *   You should have received a copy of the GNU Library General Public
- *   License along with this program; if not, write to the
- *   Free Software Foundation, Inc.,
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
- */
+    SPDX-FileCopyrightText: 2008 Chani Armitage <chani@kde.org>
+    SPDX-FileCopyrightText: 2008, 2009 Aaron Seigo <aseigo@kde.org>
+    SPDX-FileCopyrightText: 2010 Marco Martin <mart@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #ifndef APPLETINTERFACE_H
 #define APPLETINTERFACE_H
@@ -25,19 +12,25 @@
 #include <QQuickItem>
 #include <QQuickView>
 
+#include <KPluginMetaData>
+
 #include <Plasma/Applet>
 #include <Plasma/Theme>
 
-#include <appletquickitem.h>
 #include "declarativeappletscript.h"
+#include <appletquickitem.h>
 
 class QAction;
+class QActionGroup;
 class QmlAppletScript;
 class QSizeF;
+class KConfigPropertyMap;
 
 namespace KDeclarative
 {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 class ConfigPropertyMap;
+#endif
 class QmlObject;
 }
 
@@ -99,14 +92,13 @@ class AppletInterface : public PlasmaQuick::AppletQuickItem
     Q_PROPERTY(int toolTipTextFormat READ toolTipTextFormat WRITE setToolTipTextFormat NOTIFY toolTipTextFormatChanged)
 
     /**
-     * This allows to set custom full QML items as the tooltip.
+     * This allows to set fully custom QML item as the tooltip.
      * It will ignore all texts set by setToolTipMainText or setToolTipSubText
      *
-     * @since: 5.19
+     * @since 5.19
      */
     Q_PROPERTY(QQuickItem *toolTipItem READ toolTipItem WRITE setToolTipItem NOTIFY toolTipItemChanged)
 
-
     /**
      * Icon to represent the plasmoid
      */
@@ -122,6 +114,12 @@ class AppletInterface : public PlasmaQuick::AppletQuickItem
      */
     Q_PROPERTY(Plasma::Types::FormFactor formFactor READ formFactor NOTIFY formFactorChanged)
 
+    /**
+     * Type of the containment we're in
+     * @since 5.77
+     */
+    Q_PROPERTY(Plasma::Types::ContainmentDisplayHints containmentDisplayHints READ containmentDisplayHints NOTIFY containmentDisplayHintsChanged)
+
     /**
      * Location for the plasmoid
      */
@@ -147,6 +145,16 @@ class AppletInterface : public PlasmaQuick::AppletQuickItem
      */
     Q_PROPERTY(Plasma::Types::BackgroundHints backgroundHints WRITE setBackgroundHints READ backgroundHints NOTIFY backgroundHintsChanged)
 
+    /**
+     * The containment (and/or the user) may decide to use another kind of background instead (if supported by the applet)
+     */
+    Q_PROPERTY(Plasma::Types::BackgroundHints userBackgroundHints WRITE setUserBackgroundHints READ userBackgroundHints NOTIFY userBackgroundHintsChanged)
+
+    /**
+     * The effective background hints the applet has, internally decided how to mix with userBackgroundHints
+     */
+    Q_PROPERTY(Plasma::Types::BackgroundHints effectiveBackgroundHints READ effectiveBackgroundHints NOTIFY effectiveBackgroundHintsChanged)
+
     /**
      * Whether the Corona is immutable. The plasmoid implementation should avoid allowing "dangerous" modifications from the user when in an immutable mode
      *
@@ -209,7 +217,7 @@ class AppletInterface : public PlasmaQuick::AppletQuickItem
      * This is typically only used by the default configuration module
      *
      */
-    Q_PROPERTY(QKeySequence globalShortcut READ globalShortcut WRITE setGlobalShortcut NOTIFY globalShortcutChanged)
+    Q_PROPERTY(QKeySequence globalShortcut READ globalShortcut WRITE setGlobalShortcut RESET setGlobalShortcut NOTIFY globalShortcutChanged)
 
     /**
      * An interface to the native C++ plasmoid, if implemented
@@ -224,7 +232,8 @@ class AppletInterface : public PlasmaQuick::AppletQuickItem
     /**
      * Reason why the manual user configuration is required
      */
-    Q_PROPERTY(QString configurationRequiredReason READ configurationRequiredReason WRITE setConfigurationRequiredReason NOTIFY configurationRequiredReasonChanged)
+    Q_PROPERTY(
+        QString configurationRequiredReason READ configurationRequiredReason WRITE setConfigurationRequiredReason NOTIFY configurationRequiredReasonChanged)
 
     /**
      * screen area free of panels: the coordinates are relative to the containment,
@@ -238,19 +247,37 @@ class AppletInterface : public PlasmaQuick::AppletQuickItem
      */
     Q_PROPERTY(QVariantList availableScreenRegion READ availableScreenRegion NOTIFY availableScreenRegionChanged)
 
+    Q_PROPERTY(bool loading MEMBER m_loading NOTIFY isLoadingChanged)
+
+    /**
+     * The hints that the applet gives to its constraint,
+     * such as asking to fill all the available space ignoring margins.
+     */
+    Q_PROPERTY(Plasma::Types::ConstraintHints constraintHints READ constraintHints WRITE setConstraintHints NOTIFY constraintHintsChanged)
+
+    /**
+     * The metadata of the applet.
+     * @since 5.73
+     */
+    Q_PROPERTY(KPluginMetaData metaData READ metaData CONSTANT)
+
+    Q_PROPERTY(QList<QObject *> contextualActions READ contextualActionsObjects NOTIFY contextualActionsChanged)
 public:
     AppletInterface(DeclarativeAppletScript *script, const QVariantList &args = QVariantList(), QQuickItem *parent = nullptr);
     ~AppletInterface() override;
 
-//API not intended for the QML part
+    // API not intended for the QML part
 
     DeclarativeAppletScript *appletScript() const;
 
+    // This is for QML which only supports QList<QObject *>
+    QList<QObject *> contextualActionsObjects() const;
+
     QList<QAction *> contextualActions() const;
 
     void executeAction(const QString &name);
 
-//QML API-------------------------------------------------------------------
+    // QML API-------------------------------------------------------------------
 
     /**
      * Set this to true if the plasmoid needs to be configured in order to work. The containment will display reason as a message to ask the user to configure.
@@ -260,16 +287,18 @@ public:
     Q_INVOKABLE void setConfigurationRequired(bool needsConfiguring, const QString &reason = QString());
 
     Q_INVOKABLE void setActionSeparator(const QString &name);
+
+    Q_INVOKABLE void setActionGroup(const QString &action, const QString &group);
     /**
      * Add an action to the Plasmoid contextual menu.
-     * When the action is triggered a function called action_<name> will be called, if there is no function with that name actionTriggered(name) will be called instead.
+     * When the action is triggered a function called action_<name> will be called, if there is no function with that name actionTriggered(name) will be called
+     * instead.
      * @param: action name
      * @text: user visible displayed text
      * @icon: user visible optional displayed icon
      * @shortcut: shortcut to trigger this action
      */
-    Q_INVOKABLE void setAction(const QString &name, const QString &text,
-                               const QString &icon = QString(), const QString &shortcut = QString());
+    Q_INVOKABLE void setAction(const QString &name, const QString &text, const QString &icon = QString(), const QString &shortcut = QString());
 
     Q_INVOKABLE void removeAction(const QString &name);
 
@@ -311,7 +340,7 @@ public:
     /**
      * @returns A path where it is safe to write on disk downloaded files.
      * @param file that name of the file to download (unused).
-     * @deprecated Use downloadPath() instead.
+     * @deprecated Since 5,23, use downloadPath() instead.
      */
     Q_INVOKABLE PLASMA_DEPRECATED QString downloadPath(const QString &file);
 
@@ -329,7 +358,7 @@ public:
         return qobject_cast<AppletInterface *>(AppletQuickItem::qmlAttachedProperties(object));
     }
 
-//PROPERTY ACCESSORS-------------------------------------------------------------------
+    // PROPERTY ACCESSORS-------------------------------------------------------------------
     QString pluginName() const;
 
     QString icon() const;
@@ -356,6 +385,8 @@ public:
 
     Plasma::Types::Location location() const;
 
+    Plasma::Types::ContainmentDisplayHints containmentDisplayHints() const;
+
     QString currentActivity() const;
 
     QObject *configuration() const;
@@ -366,6 +397,11 @@ public:
     Plasma::Types::BackgroundHints backgroundHints() const;
     void setBackgroundHints(Plasma::Types::BackgroundHints hint);
 
+    Plasma::Types::BackgroundHints userBackgroundHints() const;
+    void setUserBackgroundHints(Plasma::Types::BackgroundHints hint);
+
+    Plasma::Types::BackgroundHints effectiveBackgroundHints() const;
+
     void setAssociatedApplication(const QString &string);
     QString associatedApplication() const;
 
@@ -387,17 +423,21 @@ public:
     void setHideOnWindowDeactivate(bool hide);
 
     QKeySequence globalShortcut() const;
-    void setGlobalShortcut(const QKeySequence &keySequence);
+    void setGlobalShortcut(const QKeySequence &keySequence = QKeySequence());
 
     QObject *nativeInterface();
 
-    //NOTE: setConfigurationRequiredProperty because ambiguous with the
+    // NOTE: setConfigurationRequiredProperty because ambiguous with the
     // setConfigurationRequired invokable
     bool configurationRequired() const;
     void setConfigurationRequiredProperty(bool required);
 
     QString configurationRequiredReason() const;
     void setConfigurationRequiredReason(const QString &reason);
+    Plasma::Types::ConstraintHints constraintHints() const;
+    void setConstraintHints(Plasma::Types::ConstraintHints constraintHints);
+
+    KPluginMetaData metaData() const;
 
 Q_SIGNALS:
     /**
@@ -421,7 +461,7 @@ Q_SIGNALS:
      */
     void contextualActionsAboutToShow();
 
-//PROPERTY change notifiers--------------
+    // PROPERTY change notifiers--------------
     void iconChanged();
     void titleChanged();
     void toolTipMainTextChanged();
@@ -430,10 +470,13 @@ Q_SIGNALS:
     void toolTipItemChanged();
     void formFactorChanged();
     void locationChanged();
+    void containmentDisplayHintsChanged();
     void contextChanged();
     void immutabilityChanged();
     void statusChanged();
     void backgroundHintsChanged();
+    void userBackgroundHintsChanged();
+    void effectiveBackgroundHintsChanged();
     void busyChanged();
     void screenChanged();
     void screenGeometryChanged();
@@ -442,12 +485,16 @@ Q_SIGNALS:
     void associatedApplicationUrlsChanged();
     void availableScreenRegionChanged();
     void availableScreenRectChanged();
+    void constraintHintsChanged();
+    void contextualActionsChanged();
 
     void userConfiguringChanged();
     void globalShortcutChanged();
     void configurationRequiredChanged();
     void configurationRequiredReasonChanged();
 
+    void isLoadingChanged();
+
 protected Q_SLOTS:
     void init() override;
 
@@ -455,32 +502,46 @@ protected:
     bool event(QEvent *event) override;
     bool eventFilter(QObject *watched, QEvent *event) override;
 
+    /*
+     * Returns true if this plasmoid or a dependent feature (i.e wallpaper) is loading
+     */
+    virtual bool isLoading() const;
+    /*
+     * Set UIReadyConstraint if we're not currently loading
+     */
+    void updateUiReadyConstraint();
+
 private Q_SLOTS:
     void destroyedChanged(bool destroyed);
 
 private:
-
     QStringList m_actions;
+    QHash<QString, QActionGroup *> m_actionGroups;
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     KDeclarative::ConfigPropertyMap *m_configuration;
+#else
+    KConfigPropertyMap *m_configuration;
+#endif
     DeclarativeAppletScript *m_appletScriptEngine;
 
-//UI-specific members ------------------
+    // UI-specific members ------------------
 
     QString m_toolTipMainText;
     QString m_toolTipSubText;
     int m_toolTipTextFormat;
     QPointer<QQuickItem> m_toolTipItem;
     QVariantList m_args;
-    Plasma::Types::BackgroundHints m_backgroundHints;
     bool m_hideOnDeactivate : 1;
-    //this is used to build an emacs style shortcut
+    bool m_loading = false;
+    // this is used to build an emacs style shortcut
     int m_oldKeyboardShortcut;
     QObject *m_dummyNativeInterface;
 
     friend class ContainmentInterface;
-    //This is used by ContainmentInterface
+    // This is used by ContainmentInterface
     QPointF m_positionBeforeRemoval;
+    Plasma::Types::ConstraintHints m_constraintHints = Plasma::Types::ConstraintHints::NoHint;
 };
 
 QML_DECLARE_TYPEINFO(AppletInterface, QML_HAS_ATTACHED_PROPERTIES)
