@@ -7,19 +7,22 @@
 #ifndef WALLPAPERINTERFACE_H
 #define WALLPAPERINTERFACE_H
 
-#include <QQuickItem>
 #include <QQmlEngine>
+#include <QQuickItem>
 
 #include <KPackage/Package>
 
 class KConfigLoader;
 class KActionCollection;
+class KConfigPropertyMap;
 
 class ContainmentInterface;
 
 namespace KDeclarative
 {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 class ConfigPropertyMap;
+#endif
 class QmlObject;
 }
 
@@ -35,12 +38,16 @@ class WallpaperInterface : public QQuickItem
     Q_OBJECT
 
     Q_PROPERTY(QString pluginName READ pluginName NOTIFY packageChanged)
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     Q_PROPERTY(KDeclarative::ConfigPropertyMap *configuration READ configuration NOTIFY configurationChanged)
+#else
+    Q_PROPERTY(KConfigPropertyMap *configuration READ configuration NOTIFY configurationChanged)
+#endif
     Q_PROPERTY(bool loading MEMBER m_loading NOTIFY isLoadingChanged)
 
 public:
     explicit WallpaperInterface(ContainmentInterface *parent = nullptr);
-    ~WallpaperInterface();
+    ~WallpaperInterface() override;
 
     /**
      * Returns a list of all known wallpapers that can accept the given mimetype
@@ -48,14 +55,17 @@ public:
      * @param formFactor the format of the wallpaper being search for (e.g. desktop)
      * @return list of wallpapers
      */
-    static QList<KPluginMetaData> listWallpaperMetadataForMimetype(const QString &mimetype,
-            const QString &formFactor = QString());
+    static QList<KPluginMetaData> listWallpaperMetadataForMimetype(const QString &mimetype, const QString &formFactor = QString());
 
     KPackage::Package kPackage() const;
 
     QString pluginName() const;
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     KDeclarative::ConfigPropertyMap *configuration() const;
+#else
+    KConfigPropertyMap *configuration() const;
+#endif
 
     KConfigLoader *configScheme();
 
@@ -65,8 +75,7 @@ public:
 
     void setUrl(const QUrl &urls);
 
-    Q_INVOKABLE void setAction(const QString &name, const QString &text,
-                               const QString &icon = QString(), const QString &shortcut = QString());
+    Q_INVOKABLE void setAction(const QString &name, const QString &text, const QString &icon = QString(), const QString &shortcut = QString());
 
     Q_INVOKABLE void removeAction(const QString &name);
 
@@ -91,7 +100,11 @@ private:
     ContainmentInterface *m_containmentInterface;
     KDeclarative::QmlObject *m_qmlObject;
     KPackage::Package m_pkg;
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     KDeclarative::ConfigPropertyMap *m_configuration;
+#else
+    KConfigPropertyMap *m_configuration;
+#endif
     KConfigLoader *m_configLoader;
     KActionCollection *m_actions;
     bool m_loading = false;
